@@ -29,7 +29,7 @@ class Correlation(Amplitude):
     #: A tuple of tuples of Floats specifying the real and imaginary part of the scaling
     #: factor. If **approach** = MOVING_NOISE, then **data** represents the noise velocity components
     #: 1, 2, and 3.
-    data: float | None = None
+    data: tuple[tuple[float, ...], ...] = ()
 
     #: A SymbolicConstant specifying the time span of the amplitude. Possible values are STEP
     #: and TOTAL. The default value is STEP.
