@@ -61,7 +61,20 @@ class Arrow(Annotation, _OptionsBase):
     #: - TOP_RIGHT
     #:
     #: The default value is BOTTOM_LEFT.
-    startAnchor: Union[SymbolicConstant, float] = BOTTOM_LEFT
+    startAnchor: Union[
+        Literal[
+            C.CENTER_RIGHT,
+            C.TOP_CENTER,
+            C.BOTTOM_RIGHT,
+            C.BOTTOM_LEFT,
+            C.CENTER,
+            C.TOP_RIGHT,
+            C.CENTER_LEFT,
+            C.TOP_LEFT,
+            C.BOTTOM_CENTER,
+        ],
+        tuple[float, ...],
+    ] = BOTTOM_LEFT
 
     #: A SymbolicConstant or a sequence of Floats specifying a point. A sequence of two Floats
     #: specifies the **X**  and **Y** coordinates as percentages of the viewport width and height.
@@ -80,7 +93,20 @@ class Arrow(Annotation, _OptionsBase):
     #: - TOP_RIGHT
     #:
     #: The default value is BOTTOM_LEFT.
-    endAnchor: Union[SymbolicConstant, float] = BOTTOM_LEFT
+    endAnchor: Union[
+        Literal[
+            C.CENTER_RIGHT,
+            C.TOP_CENTER,
+            C.BOTTOM_RIGHT,
+            C.BOTTOM_LEFT,
+            C.CENTER,
+            C.TOP_RIGHT,
+            C.CENTER_LEFT,
+            C.TOP_LEFT,
+            C.BOTTOM_CENTER,
+        ],
+        tuple[float, ...],
+    ] = BOTTOM_LEFT
 
     #: A SymbolicConstant specifying the style of the start head. Possible values are:
     #:
@@ -150,7 +176,7 @@ class Arrow(Annotation, _OptionsBase):
                 C.TOP_LEFT,
                 C.BOTTOM_CENTER,
             ],
-            float,
+            tuple[float, ...],
         ] = BOTTOM_LEFT,
         endAnchor: Union[
             Literal[
@@ -164,7 +190,7 @@ class Arrow(Annotation, _OptionsBase):
                 C.TOP_LEFT,
                 C.BOTTOM_CENTER,
             ],
-            float,
+            tuple[float, ...],
         ] = BOTTOM_LEFT,
         startHeadStyle: Literal[
             C.FILLED_DIAMOND,
