@@ -4,6 +4,7 @@ from typing import Sequence, Union, overload
 
 from typing_extensions import Literal
 
+from abaqus.Datum.DatumCsys import DatumCsys
 from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
 
 from ..BasicGeometry.Edge import Edge
@@ -93,7 +94,7 @@ class AssemblyBase(AssemblyFeature):
     instances: dict[str, PartInstance] = {}
 
     #: A repository of Datum objects specifying all Datum objects in the assembly.
-    datums: list[Datum] = []
+    datums: dict[int, Datum] = {}
 
     #: A repository of Feature objects specifying all Feature objects in the assembly.
     features: dict[str, AssemblyFeature] = {}
@@ -635,13 +636,20 @@ class AssemblyBase(AssemblyFeature):
         ...
 
     @abaqus_method_doc
-    def getCoordinates(self, entity: str):
+    def getCoordinates(self, entity: str, csys: DatumCsys = DatumCsys()):
         """This method returns the coordinates of a specified point.
 
         Parameters
         ----------
         entity
             A ConstrainedSketchVertex, Datum point, MeshNode, or ReferencePoint specifying the entity to query.
+        csys
+            A DatumCsys object specifying the desired coordinate system of the returned coordinates. By default,
+            coordinates are given in the global coordinate system.
+
+            .. versionadded:: 2023
+
+                The ``csys`` argument was added.
 
         Returns
         -------
@@ -651,13 +659,17 @@ class AssemblyBase(AssemblyFeature):
         ...
 
     @abaqus_method_doc
-    def getDistance(self, entity1: str, entity2: str, printResults: Boolean = OFF):
+    def getDistance(self, entity1: str, entity2: str, printResults: Boolean = OFF, csys: DatumCsys = DatumCsys()):
         """Depending on the arguments provided, this method returns one of the following:
 
         - The distance between two points.
         - The minimum distance between a point and an edge.
         - The minimum distance between two edges.
 
+        .. versionchanged:: 2023
+
+            The ``csys`` argument was removed.
+
         Parameters
         ----------
         entity1
@@ -1151,5 +1163,8 @@ class AssemblyBase(AssemblyFeature):
         ----------
         nodes
             A sequence of MeshNode objects or a Set object containing nodes.
+
+            .. versionchanged:: 2020
+                The ``coordinates`` arguments was removed, the ``nodes`` now replaces it.
         """
         ...
