@@ -1484,6 +1484,7 @@ class BoundaryConditionModel(ModelBase):
         localCsys: str | None = None,
         globalIncrement: int = 0,
         centerZoneSize: float | None = None,
+        intersectionOnly: Boolean = OFF,
     ) -> SubmodelBC:
         """This method creates a SubmodelBC object.
 
@@ -1538,6 +1539,13 @@ class BoundaryConditionModel(ModelBase):
         centerZoneSize
             A Float specifying the thickness of the center zone size around the shell midsurface.
             The default value is None.
+        intersectionOnly
+            A Boolean specifying whether to ignore driven nodes that lie outside the region of
+            elements of the global model after accounting for the exterior search tolerance. The
+            default value is OFF.
+
+            .. versionadded:: 2021
+                The ``intersectionOnly`` argument was added.
 
         Returns
         -------
@@ -1558,6 +1566,7 @@ class BoundaryConditionModel(ModelBase):
             localCsys,
             globalIncrement,
             centerZoneSize,
+            intersectionOnly,
         )
         self.steps[createStepName].boundaryConditionStates[name] = SubmodelBCState()
         return boundaryCondition
@@ -1906,7 +1915,7 @@ class BoundaryConditionModel(ModelBase):
         .. note::
             This function can be accessed by::
 
-                mdb.models[name].EncastreBC
+                mdb.models[name].XsymmBC
 
         Parameters
         ----------
@@ -2004,7 +2013,7 @@ class BoundaryConditionModel(ModelBase):
         .. note::
             This function can be accessed by::
 
-                mdb.models[name].EncastreBC
+                mdb.models[name].ZsymmBC
 
         Parameters
         ----------
@@ -2053,7 +2062,7 @@ class BoundaryConditionModel(ModelBase):
         .. note::
             This function can be accessed by::
 
-                mdb.models[name].EncastreBC
+                mdb.models[name].XasymmBC
 
         Parameters
         ----------
