@@ -23,6 +23,7 @@ from ..UtilityAndView.abaqusConstants import (
     SUM,
     TABULAR,
     UNCOUPLED,
+    VISCOUS,
     Boolean,
 )
 from ..UtilityAndView.abaqusConstants import abaqusConstants as C
@@ -177,6 +178,7 @@ class ConnectorSection(SectionBase):
     @abaqus_method_doc
     def ConnectorDamping(
         self,
+        type: Literal[C.STRUCTURAL, C.VISCOUS] = VISCOUS,
         behavior: Literal[C.NONLINEAR, C.LINEAR] = LINEAR,
         coupling: Literal[
             C.UNCOUPLED, C.NONLINEAR, C.COUPLED_POSITION, C.COUPLED_MOTION, C.COUPLED, C.LINEAR
@@ -200,6 +202,12 @@ class ConnectorSection(SectionBase):
 
         Parameters
         ----------
+        type
+            A SymbolicConstant specifying if the damping type is viscous or structural. Possible values are
+            VISCOUS and STRUCTURAL. The default value is VISCOUS.
+
+            .. versionadded:: 2022
+                The ``type`` argument was added.
         behavior
             A SymbolicConstant specifying if the damping behavior is linear or nonlinear. Possible
             values are LINEAR and NONLINEAR. The default value is LINEAR.
