@@ -77,6 +77,7 @@ class ConstraintModel(ModelBase):
         controlPoint: Region,
         influenceRadius: Union[Literal[C.WHOLE_SURFACE], float],
         couplingType: Literal[C.STRUCTURAL, C.DISTRIBUTING, C.KINEMATIC],
+        rotationalCouplingType: Literal[C.ROTATIONAL_CONTINUUM, C.ROTATIONAL_STRUCTURAL],
         adjust: Boolean = OFF,
         localCsys: str | None = None,
         u1: Boolean = ON,
@@ -86,6 +87,7 @@ class ConstraintModel(ModelBase):
         ur2: Boolean = ON,
         ur3: Boolean = ON,
         weightingMethod: Literal[C.QUADRATIC, C.DISTRIBUTING, C.UNIFORM, C.LINEAR, C.CUBIC] = UNIFORM,
+        alpha: float = 0.0,
     ) -> Coupling:
         """This method creates a Coupling object.
 
@@ -107,6 +109,13 @@ class ConstraintModel(ModelBase):
         couplingType
             A SymbolicConstant specifying the coupling constraint type. Possible values are
             KINEMATIC, DISTRIBUTING, and STRUCTURAL.
+        rotationalCouplingType
+            A SymbolicConstant specifying the rotational coupling constraint type. Possible values are
+            ROTATIONAL_CONTINUUM and ROTATIONAL_STRUCTURAL.
+
+            .. versionadded:: 2024
+
+                The ``rotationalCouplingType`` argument was added.
         adjust
             A Boolean specifying if the control point will be adjusted (moved) to the surface. The
             point will be adjusted in the direction normal to the specified surface. The default
@@ -144,6 +153,12 @@ class ConstraintModel(ModelBase):
             distributing weight factors. Possible values are UNIFORM, LINEAR, QUADRATIC, and CUBIC.
             The default value is UNIFORM.The **weightingMethod** argument applies only when
             **couplingType** = DISTRIBUTING.
+        alpha
+            A Float specifying the value of the thermal expansion coefficient. The default value is 0.0.
+            The alpha argument applies only when couplingType=KINEMATIC.
+
+            .. versionadded:: 2022
+                The ``alpha`` argument was added.
 
         Returns
         -------
@@ -165,6 +180,7 @@ class ConstraintModel(ModelBase):
             ur2,
             ur3,
             weightingMethod,
+            alpha,
         )
         return constraint
 
@@ -348,11 +364,11 @@ class ConstraintModel(ModelBase):
     def RigidBody(
         self,
         name: str,
-        refPointRegion: Region,
-        bodyRegion: str | None = None,
-        tieRegion: str | None = None,
-        pinRegion: str | None = None,
-        surfaceRegion: str | None = None,
+        refPointRegion: Region | None,
+        bodyRegion: Region | None = None,
+        tieRegion: Region | None = None,
+        pinRegion: Region | None = None,
+        surfaceRegion: Region | None = None,
         refPointAtCOM: Boolean = OFF,
         isothermal: Boolean = OFF,
     ) -> RigidBody:
@@ -466,8 +482,8 @@ class ConstraintModel(ModelBase):
     def Tie(
         self,
         name: str,
-        master: Region,
-        slave: Region,
+        main: Region,
+        secondary: Region,
         adjust: Boolean = ON,
         positionToleranceMethod: Literal[C.COMPUTED, C.SPECIFIED] = COMPUTED,
         positionTolerance: float = 0,
@@ -488,13 +504,19 @@ class ConstraintModel(ModelBase):
         ----------
         name
             A String specifying the constraint repository key.
-        master
-            A Region object specifying the name of the master surface.
-        slave
-            A Region object specifying the name of the slave surface.
+        main
+            A Region object specifying the name of the main surface.
+
+            .. versionchanged:: 2022
+                The ``master`` argument was renamed to ``main``.
+        secondary
+            A Region object specifying the name of the secondary surface.
+
+            .. versionchanged:: 2022
+                The ``slave`` argument was renamed to ``secondary``.
         adjust
-            A Boolean specifying whether initial positions of tied slave nodes are adjusted to
-            lie on the master surface. The default value is ON.
+            A Boolean specifying whether initial positions of tied secondary nodes are adjusted to
+            lie on the main surface. The default value is ON.
         positionToleranceMethod
             A SymbolicConstant specifying the method used to determine the position tolerance.
             Possible values are COMPUTED and SPECIFIED. The default value is COMPUTED.
@@ -508,8 +530,8 @@ class ConstraintModel(ModelBase):
             A SymbolicConstant specifying the method used to determine the constraint ratio.
             Possible values are DEFAULT and SPECIFIED. The default value is DEFAULT.
         constraintRatio
-            A Float specifying the fractional distance between the master reference surface and the
-            slave node at which the translational constraint should act. The **constraintRatio**
+            A Float specifying the fractional distance between the main reference surface and the
+            secondary node at which the translational constraint should act. The **constraintRatio**
             argument applies only when **constraintRatioMethod** = SPECIFIED. The default value is 0.0.
         constraintEnforcement
             A SymbolicConstant specifying the discretization method. Possible values are
@@ -526,8 +548,8 @@ class ConstraintModel(ModelBase):
         """
         self.constraints[name] = constraint = Tie(
             name,
-            master,
-            slave,
+            main,
+            secondary,
             adjust,
             positionToleranceMethod,
             positionTolerance,
