@@ -24,7 +24,7 @@ class DatumPlane(Datum):
 
     #: A tuple of Floats specifying the **X**, **Y**, and **Z** coordinates of a point located on
     #: the datum.
-    pointOn: float | None = None
+    pointOn: tuple[float, ...] = ()
 
     #: A tuple of Floats specifying a sequence of three Floats specifying the normal.
-    normal: tuple = ()
+    normal: tuple[float, ...] = ()
