@@ -24,4 +24,4 @@ class DatumPoint(Datum):
 
     #: A tuple of Floats specifying the **X**, **Y**, and **Z** coordinates of a point located on
     #: the datum.
-    pointOn: float | None = None
+    pointOn: tuple[float, ...] = ()
