@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Union
+from typing import Sequence, Union
 
 from typing_extensions import Literal
 
@@ -24,15 +24,19 @@ from ..UtilityAndView.abaqusConstants import (
     STEP,
     UNIFORM,
     Boolean,
+    R,
     SymbolicConstant,
 )
 from ..UtilityAndView.abaqusConstants import abaqusConstants as C
 from .AssembledFastener import AssembledFastener
 from .ContourIntegral import ContourIntegral
+from .DataImperfection import DataImperfection
 from .DebondVCCT import DebondVCCT
 from .DiscreteFastener import DiscreteFastener
 from .EngineeringFeatureBase import EngineeringFeatureBase
+from .FileImperfection import FileImperfection
 from .HeatCapacitance import HeatCapacitance
+from .InputImperfection import InputImperfection
 from .NonstructuralMass import NonstructuralMass
 from .PointFastener import PointFastener
 from .PointMassInertia import PointMassInertia
@@ -82,11 +86,11 @@ class EngineeringFeature(EngineeringFeatureBase):
             A sequence of Strings specifying the names of the template model surfaces that are
             referenced by tie or coupling constraints.
         assignedSurfaces
-            A sequence of Strings specifying the names of the master model surfaces that will be
+            A sequence of Strings specifying the names of the main model surfaces that will be
             substituted for the template model constraint surfaces.
         propertyPrefix
             A String specifying the name of the property prefix string. This string will be
-            prepended to every property name as it is copied to the master model from the template
+            prepended to every property name as it is copied to the main model from the template
             model.
         orientMethod
             A SymbolicConstant specifying the method used to orient the virtual instances of the
@@ -272,6 +276,7 @@ class EngineeringFeature(EngineeringFeatureBase):
         ur2: Boolean = ON,
         ur3: Boolean = ON,
         coupling: Literal[C.STRUCTURAL, C.CONTINUUM] = CONTINUUM,
+        rotationalCoupling: Literal[C.ROTATIONAL_CONTINUUM, C.ROTATIONAL_STRUCTURAL] = C.ROTATIONAL_STRUCTURAL,
         weightingMethod: Literal[C.QUADRATIC, C.UNIFORM, C.CUBIC, C.LINEAR] = UNIFORM,
         localCsys: int | None = None,
     ) -> DiscreteFastener:
@@ -306,6 +311,13 @@ class EngineeringFeature(EngineeringFeatureBase):
             rotation of each attachment point to the average motion of the surface nodes within the
             radius of influence from the fastening point. Possible values are CONTINUUM and
             STRUCTURAL. The default value is CONTINUUM.
+        rotationalCoupling
+            A SymbolicConstant specifying the rotational coupling method used. Possible values are ROTATIONAL_CONTINUUM
+            and ROTATIONAL_STRUCTURAL. The default value is ROTATIONAL_STRUCTURAL.
+
+            .. versionadded:: 2024
+
+                The argument ``rotationalCoupling`` was added.
         weightingMethod
             A SymbolicConstant specifying the weighting scheme to be used to weight the contribution
             of the displacements of the surface nodes within the radius of influence to the motion
@@ -923,3 +935,114 @@ class EngineeringFeature(EngineeringFeatureBase):
             autoDetectValue,
         )
         return xFEMCrack
+
+    def FileImperfection(
+        self,
+        name: str,
+        file: str,
+        step: int,
+        linearSuperpositions: Sequence[Sequence[int]],
+        region: Region = Region(),
+        increment: int = -1,
+    ):
+        """This method creates a FileImperfection object.
+
+        .. note::
+            This function can be accessed by::
+
+                mdb.models[name].rootAssembly.engineeringFeatures.FileImperfection
+
+        Parameters
+        ----------
+        name
+            A String specifying the repository key.
+        file
+            A String specifying the results file from a previous analysis from which the file imperfection is applied.
+        step
+            An Int specifying the step number (in the analysis whose file is being used as input to this option) from
+            which the modal or displacement data are to be read.
+        linearSuperpositions
+            A sequence of sequences of Integers and Floats specifying linearSuperpositions. The items in the table data
+            are described below.
+        region
+            A Region object specifying the region to which the file imperfection is applied. By default, the
+            imperfection will be applied to all nodes in the model.
+        increment
+            An Int specifying the increment number (in the analysis whose file is being used as input to this option)
+            from which the displacement data are to be read. By default, the data will be read from the last increment
+            available for the specified step.
+
+        Returns
+        -------
+        FileImperfection
+            A FileImperfection object.
+        """
+        self.imperfections[name] = fileImperfection = FileImperfection(
+            name, file, step, linearSuperpositions, region, increment
+        )
+        return fileImperfection
+
+    def InputImperfection(
+        self,
+        name: str,
+        file: str,
+        system: Literal[C.R, C.C, C.S] = R,
+    ):
+        """This method creates a InputImperfection object.
+
+        .. note::
+            This function can be accessed by::
+
+                mdb.models[name].rootAssembly.engineeringFeatures.InputImperfection
+
+        Parameters
+        ----------
+        name
+            A String specifying the repository key.
+        file
+            A String specifying the name of the alternate input file containing the imperfection data.
+        system
+            A SymbolicConstant specifying the coordinate system. The imperfection values in the alternate input file
+            being used as input to this option would be treated as perturbation values of respective coordinates.
+            Possible values are R, C and S. The default value is R.
+
+        Returns
+        -------
+        InputImperfection
+            A InputImperfection object.
+        """
+        self.imperfections[name] = inputImperfection = InputImperfection(name, file, system)
+        return inputImperfection
+
+    def DataImperfection(
+        self,
+        name: str,
+        imperfectionTable: tuple[tuple[int | float, ...], ...],
+        system: Literal[C.R, C.C, C.S] = R,
+    ):
+        """This method creates a DataImperfection object.
+
+        .. note::
+            This function can be accessed by::
+
+                mdb.models[name].rootAssembly.engineeringFeatures.DataImperfection
+
+        Parameters
+        ----------
+        name
+            A String specifying the repository key.
+        imperfectionTable: tuple[tuple[int | float, ...], ...]
+            A sequence of sequences of Ints and Floats specifying the imperfection components at a given node. The
+            items in the table data are described below.
+        system
+            A SymbolicConstant specifying the coordinate system. The imperfection values in the data lines would be
+            treated as perturbation values of the respective coordinates. Possible values are R, C, and S. The default
+            value is R.
+
+        Returns
+        -------
+        DataImperfection
+            A DataImperfection object.
+        """
+        self.imperfections[name] = dataImperfection = DataImperfection(name, imperfectionTable, system)
+        return dataImperfection
