@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Sequence, Union, overload
+from typing import TYPE_CHECKING, Sequence, overload
 
 from typing_extensions import Literal
 
@@ -10,13 +10,11 @@ from ..BasicGeometry.Cell import Cell
 from ..BasicGeometry.Edge import Edge
 from ..BasicGeometry.Face import Face
 from ..BasicGeometry.InterestingPoint import InterestingPoint
-from ..BasicGeometry.ReferencePoint import ReferencePoint
+from ..BasicGeometry.ReferencePoint import ReferencePoint as ReferencePointType
 from ..BasicGeometry.Transform import Transform
-from ..BasicGeometry.Vertex import Vertex
 from ..Datum.Datum import Datum
-from ..Datum.DatumAxis import DatumAxis
-from ..Datum.DatumPlane import DatumPlane
 from ..Datum.DatumPoint import DatumPoint
+from ..Mesh.MeshEdge import MeshEdge
 from ..Mesh.MeshFace import MeshFace
 from ..Mesh.MeshNode import MeshNode
 from ..Sketcher.ConstrainedSketch import ConstrainedSketch, ConstrainedSketchVertex
@@ -32,6 +30,9 @@ from ..UtilityAndView.abaqusConstants import (
 )
 from ..UtilityAndView.abaqusConstants import abaqusConstants as C
 
+if TYPE_CHECKING:
+    from numpy.typing import NDArray
+
 
 @abaqus_class_doc
 class Feature:
@@ -55,13 +56,19 @@ class Feature:
     name: str = ""
 
     #: An Int specifying the ID of the feature.
-    id: int | None = None
+    id: int
 
     @abaqus_method_doc
     def AttachmentPoints(
         self,
         name: str,
-        points: float,
+        points: (
+            Sequence[ConstrainedSketchVertex]
+            | Sequence[DatumPoint]
+            | Sequence[MeshNode]
+            | Sequence[InterestingPoint]
+            | Sequence[Sequence[float]]
+        ),
         projectionMethod: Literal[C.PROJECT_BY_PROXIMITY, C.PROJECT_BY_DIRECTION] = PROJECT_BY_PROXIMITY,
         projectOnFaces: Sequence[Face] = (),
         projectOnElementFaces: Sequence[MeshFace] = (),
@@ -224,36 +231,48 @@ class Feature:
         spacingMethod: Literal[C.AUTO_FIT_PTS, C.SPECIFY_NUM_PTS] = AUTO_FIT_PTS,
         patterningMethod: Literal[C.PATTERN_ORTHOGONALLY, C.PATTERN_ALONG_DIRECTION] = C.PATTERN_ORTHOGONALLY,
         referenceFace: str = "",
-        startPointForPatternDirection: ConstrainedSketchVertex
-        | Datum
-        | ReferencePoint
-        | MeshNode
-        | InterestingPoint
-        | Sequence[float] = (0.0, 0.0, 0.0),
-        endPointForPatternDirection: ConstrainedSketchVertex
-        | Datum
-        | ReferencePoint
-        | MeshNode
-        | InterestingPoint
-        | Sequence[float] = (0.0, 0.0, 0.0),
+        startPointForPatternDirection: (
+            ConstrainedSketchVertex
+            | Datum
+            | ReferencePointType
+            | MeshNode
+            | InterestingPoint
+            | Sequence[float]
+            | NDArray
+        ) = (0.0, 0.0, 0.0),
+        endPointForPatternDirection: (
+            ConstrainedSketchVertex
+            | Datum
+            | ReferencePointType
+            | MeshNode
+            | InterestingPoint
+            | Sequence[float]
+            | NDArray
+        ) = (0.0, 0.0, 0.0),
         offsetFromEdges: str = "",
         numberOfRows: int = 1,
         spacingBetweenRows: str = "",
         projectionMethod: Literal[C.PROJECT_BY_PROXIMITY, C.PROJECT_BY_DIRECTION] = PROJECT_BY_PROXIMITY,
         projectOnFaces: Sequence[Face] = (),
         projectOnElementFaces: Sequence[MeshFace] = (),
-        projectionDirStartPt: ConstrainedSketchVertex
-        | Datum
-        | ReferencePoint
-        | MeshNode
-        | InterestingPoint
-        | Sequence[float] = (0.0, 0.0, 0.0),
-        projectionDirEndPt: ConstrainedSketchVertex
-        | Datum
-        | ReferencePoint
-        | MeshNode
-        | InterestingPoint
-        | Sequence[float] = (0.0, 0.0, 0.0),
+        projectionDirStartPt: (
+            ConstrainedSketchVertex
+            | Datum
+            | ReferencePointType
+            | MeshNode
+            | InterestingPoint
+            | Sequence[float]
+            | NDArray
+        ) = (0.0, 0.0, 0.0),
+        projectionDirEndPt: (
+            ConstrainedSketchVertex
+            | Datum
+            | ReferencePointType
+            | MeshNode
+            | InterestingPoint
+            | Sequence[float]
+            | NDArray
+        ) = (0.0, 0.0, 0.0),
         setName: str = "",
     ) -> Feature:
         """This method creates a Feature object by creating attachment points along or offset from one or more
@@ -354,7 +373,10 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def DatumAxisByCylFace(self, face: str) -> Feature:
+    def DatumAxisByCylFace(
+        self,
+        face: Face,
+    ) -> Feature:
         """This method creates a Feature object and a DatumAxis object along the axis of a cylinder or cone.
 
         .. note::
@@ -380,7 +402,11 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def DatumAxisByNormalToPlane(self, plane: str, point: int) -> Feature:
+    def DatumAxisByNormalToPlane(
+        self,
+        plane: Face | MeshFace | Datum,
+        point: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+    ) -> Feature:
         """This method creates a Feature object and a DatumAxis object normal to the specified plane and passing
         through the specified point.
 
@@ -409,7 +435,11 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def DatumAxisByParToEdge(self, edge: str, point: int) -> Feature:
+    def DatumAxisByParToEdge(
+        self,
+        edge: Edge | MeshEdge | Datum,
+        point: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+    ) -> Feature:
         """This method creates a Feature object and a DatumAxis object parallel to the specified edge and
         passing through the specified point.
 
@@ -466,7 +496,12 @@ class Feature:
 
     @overload
     @abaqus_method_doc
-    def DatumAxisByRotation(self, line: str, axis: str, angle: float) -> Feature:
+    def DatumAxisByRotation(
+        self,
+        line: Edge | Datum | MeshEdge,
+        axis: Edge | Datum | MeshEdge,
+        angle: float,
+    ) -> Feature:
         """This method creates a Feature object and a DatumAxis object in a three-dimensional model by rotating
         a line about the specified axis through the specified angle.
 
@@ -500,7 +535,12 @@ class Feature:
 
     @overload
     @abaqus_method_doc
-    def DatumAxisByRotation(self, line: str, point: int, angle: float) -> Feature:
+    def DatumAxisByRotation(
+        self,
+        line: Edge | Datum | MeshEdge,
+        point: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+        angle: float,
+    ) -> Feature:
         """This method creates a Feature object and a DatumAxis object in a two-dimensional model by rotating a
         line about the specified point through the specified angle.
 
@@ -536,7 +576,12 @@ class Feature:
     def DatumAxisByRotation(self, *args, **kwargs) -> Feature:
         return Feature()
 
-    def DatumAxisByThreePoint(self, point1: int, point2: int, point3: int) -> Feature:
+    def DatumAxisByThreePoint(
+        self,
+        point1: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+        point2: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+        point3: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+    ) -> Feature:
         """This method creates a Feature object and a DatumAxis object normal to the circle described by three
         points and through its center.
 
@@ -570,7 +615,7 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def DatumAxisByThruEdge(self, edge: str) -> Feature:
+    def DatumAxisByThruEdge(self, edge: Edge | MeshEdge) -> Feature:
         """This method creates a Feature object and a DatumAxis object along the specified edge.
 
         .. note::
@@ -596,7 +641,11 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def DatumAxisByTwoPlane(self, plane1: str, plane2: str) -> Feature:
+    def DatumAxisByTwoPlane(
+        self,
+        plane1: Face | MeshFace | Datum,
+        plane2: Face | MeshFace | Datum,
+    ) -> Feature:
         """This method creates a Feature object and a DatumAxis object at the intersection of two planes.
 
         .. note::
@@ -624,7 +673,11 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def DatumAxisByTwoPoint(self, point1: int, point2: int) -> Feature:
+    def DatumAxisByTwoPoint(
+        self,
+        point1: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+        point2: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+    ) -> Feature:
         """This method creates a Feature object and a DatumAxis object along the line joining two points.
 
         .. note::
@@ -690,8 +743,8 @@ class Feature:
         self,
         coordSysType: Literal[C.CARTESIAN, C.CYLINDRICAL, C.SPHERICAL],
         datumCoordSys: Datum,
-        vector: tuple,
-        point: str,
+        vector: Sequence[float] | NDArray,
+        point: ConstrainedSketchVertex | DatumPoint | InterestingPoint | Sequence[float] | NDArray,
         name: str = "",
     ) -> Feature:
         """This method creates a Feature object and a DatumCsys object by offsetting the origin of an existing
@@ -737,11 +790,11 @@ class Feature:
     def DatumCsysByThreePoints(
         self,
         coordSysType: Literal[C.CARTESIAN, C.CYLINDRICAL, C.SPHERICAL],
-        origin: int,
-        point1: int,
-        point2: int,
-        line1: str,
-        line2: str,
+        origin: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+        point1: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+        point2: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+        line1: Edge | Datum | MeshEdge,
+        line2: Edge | Datum | MeshEdge,
         name: str = "",
     ) -> Feature:
         """This method creates a Feature object and a DatumCsys object from three points.
@@ -794,8 +847,8 @@ class Feature:
     def DatumCsysByTwoLines(
         self,
         coordSysType: Literal[C.CARTESIAN, C.CYLINDRICAL, C.SPHERICAL],
-        line1: str,
-        line2: str,
+        line1: Edge | MeshEdge | Datum,
+        line2: Edge | MeshEdge | Datum,
         name: str = "",
     ) -> Feature:
         """This method creates a Feature object and a DatumCsys object from two orthogonal lines. The origin of
@@ -866,7 +919,12 @@ class Feature:
 
     @overload
     @abaqus_method_doc
-    def DatumPlaneByOffset(self, plane: str, flip: Literal[C.SIDE1, C.SIDE2], offset: float) -> Feature:
+    def DatumPlaneByOffset(
+        self,
+        plane: Face | MeshFace | Datum,
+        flip: Literal[C.SIDE1, C.SIDE2],
+        offset: float,
+    ) -> Feature:
         """This method creates a Feature object and a DatumPlane object offset by a specified distance from an
         existing plane.
 
@@ -899,7 +957,11 @@ class Feature:
 
     @overload
     @abaqus_method_doc
-    def DatumPlaneByOffset(self, plane: str, point: int) -> Feature:
+    def DatumPlaneByOffset(
+        self,
+        plane: Face | MeshFace | Datum,
+        point: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+    ) -> Feature:
         """This method creates a Feature object and a DatumPlane object offset from an existing plane and
         passing through the specified point.
 
@@ -931,7 +993,12 @@ class Feature:
     def DatumPlaneByOffset(self, *args, **kwargs) -> Feature:
         return Feature()
 
-    def DatumPlaneByRotation(self, plane: str, axis: str, angle: float) -> Feature:
+    def DatumPlaneByRotation(
+        self,
+        plane: Face | MeshFace | Datum,
+        axis: Edge | MeshEdge | Datum,
+        angle: float,
+    ) -> Feature:
         """This method creates a Feature object and a DatumPlane object by rotating a plane about the specified
         axis through the specified angle.
 
@@ -962,7 +1029,12 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def DatumPlaneByThreePoints(self, point1: int, point2: int, point3: int) -> Feature:
+    def DatumPlaneByThreePoints(
+        self,
+        point1: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+        point2: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+        point3: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+    ) -> Feature:
         """This method creates a Feature object and a DatumPlane object defined by passing through three points.
 
         .. note::
@@ -992,7 +1064,11 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def DatumPlaneByLinePoint(self, line: str, point: int) -> Feature:
+    def DatumPlaneByLinePoint(
+        self,
+        line: Edge | Datum | MeshEdge,
+        point: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+    ) -> Feature:
         """This method creates a Feature object and a DatumPlane object that pass through the specified line and
         through the specified point that does not lie on the line.
 
@@ -1021,7 +1097,11 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def DatumPlaneByPointNormal(self, point: int, normal: str) -> Feature:
+    def DatumPlaneByPointNormal(
+        self,
+        point: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+        normal: Edge | MeshEdge | Datum,
+    ) -> Feature:
         """This method creates a Feature object and a DatumPlane object normal to the specified line and running
         through the specified point.
 
@@ -1050,7 +1130,11 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def DatumPlaneByTwoPoint(self, point1: int, point2: int) -> Feature:
+    def DatumPlaneByTwoPoint(
+        self,
+        point1: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+        point2: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+    ) -> Feature:
         """This method creates a Feature object and a DatumPlane object midway between two points and normal to
         the line connecting the points.
 
@@ -1079,7 +1163,7 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def DatumPointByCoordinate(self, coords: tuple[float, float, float]) -> Feature:
+    def DatumPointByCoordinate(self, coords: Sequence[float] | NDArray) -> Feature:
         """This method creates a Feature object and a DatumPoint object at the point defined by the specified
         coordinates.
 
@@ -1103,7 +1187,11 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def DatumPointByOffset(self, point: int, vector: tuple) -> Feature:
+    def DatumPointByOffset(
+        self,
+        point: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+        vector: Sequence[float] | NDArray,
+    ) -> Feature:
         """This method creates a Feature object and a DatumPoint object offset from an existing point by a
         vector.
 
@@ -1128,7 +1216,11 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def DatumPointByMidPoint(self, point1: int, point2: int) -> Feature:
+    def DatumPointByMidPoint(
+        self,
+        point1: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+        point2: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+    ) -> Feature:
         """This method creates a Feature object and a DatumPoint object midway between two points.
 
         .. note::
@@ -1152,7 +1244,14 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def DatumPointByOnFace(self, face: str, edge1: str, offset1: float, edge2: str, offset2: float) -> Feature:
+    def DatumPointByOnFace(
+        self,
+        face: Face | Datum,
+        edge1: Edge | Datum,
+        offset1: float,
+        edge2: Edge | Datum,
+        offset2: float,
+    ) -> Feature:
         """This method creates a Feature object and a DatumPoint object on the specified face, offset from two
         edges.
 
@@ -1218,7 +1317,11 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def DatumPointByProjOnEdge(self, point: int, edge: str) -> Feature:
+    def DatumPointByProjOnEdge(
+        self,
+        point: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+        edge: Edge | MeshEdge | Datum,
+    ) -> Feature:
         """This method creates a Feature object and a DatumPoint object along an edge by projecting an existing
         point along the normal to the edge.
 
@@ -1247,7 +1350,11 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def DatumPointByProjOnFace(self, point: int, face: Face) -> Feature:
+    def DatumPointByProjOnFace(
+        self,
+        point: ConstrainedSketchVertex | DatumPoint | MeshNode | InterestingPoint | Sequence[float] | NDArray,
+        face: Face | Datum,
+    ) -> Feature:
         """This method creates a Feature object and a DatumPoint object on a specified face by projecting an
         existing point onto the face.
 
@@ -1279,11 +1386,11 @@ class Feature:
     @abaqus_method_doc
     def MakeSketchTransform(
         self,
-        sketchPlane: Union[DatumPlane, Face],
+        sketchPlane: Datum | Face,
         origin: tuple = (),
         sketchOrientation: Literal[C.RIGHT, C.LEFT, C.TOP, C.BOTTOM] = RIGHT,
         sketchPlaneSide: Literal[C.SIDE1, C.SIDE2] = SIDE1,
-        sketchUpEdge: Union[Edge, DatumAxis, None] = None,
+        sketchUpEdge: Edge | Datum | None = None,
     ) -> Transform:
         """This method creates a Transform object. A Transform object is a 4x3 matrix of Floats that represents
         the transformation from sketch coordinates to part coordinates.
@@ -1326,7 +1433,7 @@ class Feature:
         return Transform()
 
     @abaqus_method_doc
-    def PartitionCellByDatumPlane(self, cells: Sequence[Cell], datumPlane: DatumPlane) -> Feature:
+    def PartitionCellByDatumPlane(self, cells: Sequence[Cell], datumPlane: Datum) -> Feature:
         """This method partitions one or more cells using the given datum plane.
 
         .. note::
@@ -1384,7 +1491,11 @@ class Feature:
 
     @abaqus_method_doc
     def PartitionCellByExtrudeEdge(
-        self, cells: Sequence[Cell], edges: str, line: str, sense: Literal[C.FORWARD, C.REVERSE]
+        self,
+        cells: Sequence[Cell],
+        edges: Edge,
+        line: Edge | Datum,
+        sense: Literal[C.FORWARD, C.REVERSE],
     ) -> Feature:
         """This method partitions one or more cells by extruding selected edges in the given direction.
 
@@ -1421,7 +1532,11 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def PartitionCellByPatchNCorners(self, cell: Cell, cornerPoints: tuple) -> Feature:
+    def PartitionCellByPatchNCorners(
+        self,
+        cell: Cell,
+        cornerPoints: Sequence[ConstrainedSketchVertex] | Sequence[InterestingPoint] | Sequence[DatumPoint],
+    ) -> Feature:
         """This method partitions a cell using an N-sided cutting patch defined by the given corner points.
 
         .. note::
@@ -1450,7 +1565,11 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def PartitionCellByPatchNEdges(self, cell: str, edges: Sequence[Edge]) -> Feature:
+    def PartitionCellByPatchNEdges(
+        self,
+        cell: Cell,
+        edges: Sequence[Edge],
+    ) -> Feature:
         """This method partitions a cell using an N-sided cutting patch defined by the given edges.
 
         .. note::
@@ -1483,7 +1602,7 @@ class Feature:
         self,
         cells: Sequence[Cell],
         edge: Edge,
-        point: Union[ConstrainedSketchVertex, InterestingPoint, DatumPoint],
+        point: ConstrainedSketchVertex | InterestingPoint | DatumPoint,
     ) -> Feature:
         """This method partitions one or more cells using a plane normal to an edge at the given edge point.
 
@@ -1517,8 +1636,8 @@ class Feature:
     def PartitionCellByPlanePointNormal(
         self,
         cells: Sequence[Cell],
-        point: Union[ConstrainedSketchVertex, InterestingPoint, DatumPoint],
-        normal: Union[Edge, DatumAxis],
+        point: ConstrainedSketchVertex | InterestingPoint | DatumPoint,
+        normal: Edge | Datum,
     ) -> Feature:
         """This method partitions one or more cells using a plane defined by a point and a normal direction.
 
@@ -1549,7 +1668,13 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def PartitionCellByPlaneThreePoints(self, cells: Sequence[Cell], point1: int, point2: int, point3: int) -> Feature:
+    def PartitionCellByPlaneThreePoints(
+        self,
+        cells: Sequence[Cell],
+        point1: ConstrainedSketchVertex | DatumPoint | InterestingPoint | Sequence[float] | NDArray,
+        point2: ConstrainedSketchVertex | DatumPoint | InterestingPoint | Sequence[float] | NDArray,
+        point3: ConstrainedSketchVertex | DatumPoint | InterestingPoint | Sequence[float] | NDArray,
+    ) -> Feature:
         """This method partitions one or more cells using a plane defined by three points.
 
         .. note::
@@ -1615,7 +1740,7 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def PartitionEdgeByDatumPlane(self, edges: Sequence[Edge], datumPlane: DatumPlane) -> Feature:
+    def PartitionEdgeByDatumPlane(self, edges: Sequence[Edge], datumPlane: Datum) -> Feature:
         """This method partitions an edge where it intersects with a datum plane.
 
         .. note::
@@ -1672,7 +1797,11 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def PartitionEdgeByPoint(self, edge: Edge, point: int) -> Feature:
+    def PartitionEdgeByPoint(
+        self,
+        edge: Edge,
+        point: DatumPoint | InterestingPoint | Sequence[float] | NDArray,
+    ) -> Feature:
         """This method partitions an edge at the given point.
 
         .. note::
@@ -1763,7 +1892,12 @@ class Feature:
 
     @abaqus_method_doc
     def PartitionFaceByCurvedPathEdgePoints(
-        self, face: Face, edge1: Edge, point1: int, edge2: Edge, point2: int
+        self,
+        face: Face,
+        edge1: Edge,
+        point1: ConstrainedSketchVertex | DatumPoint | InterestingPoint | Sequence[float] | NDArray,
+        edge2: Edge,
+        point2: ConstrainedSketchVertex | DatumPoint | InterestingPoint | Sequence[float] | NDArray,
     ) -> Feature:
         """This method partitions a face normal to two edges, using a curved path between the two given edge
         points.
@@ -1799,7 +1933,7 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def PartitionFaceByDatumPlane(self, faces: Sequence[Face], datumPlane: DatumPlane) -> Feature:
+    def PartitionFaceByDatumPlane(self, faces: Sequence[Face], datumPlane: Datum) -> Feature:
         """This method partitions one or more faces using the given datum plane.
 
         .. note::
@@ -1906,7 +2040,12 @@ class Feature:
         return Feature()
 
     @abaqus_method_doc
-    def PartitionFaceByShortestPath(self, faces: Sequence[Face], point1: int, point2: int) -> Feature:
+    def PartitionFaceByShortestPath(
+        self,
+        faces: Sequence[Face],
+        point1: ConstrainedSketchVertex | DatumPoint | InterestingPoint | Sequence[float] | NDArray,
+        point2: ConstrainedSketchVertex | DatumPoint | InterestingPoint | Sequence[float] | NDArray,
+    ) -> Feature:
         """This method partitions one or more faces using a minimum distance path between the two given points.
 
         .. note::
@@ -1982,7 +2121,7 @@ class Feature:
     def PartitionFaceBySketchDistance(
         self,
         faces: Sequence[Face],
-        sketchPlane: str,
+        sketchPlane: Face | Datum,
         sketchPlaneSide: Literal[C.SIDE1, C.SIDE2],
         sketchUpEdge: Edge,
         sketch: ConstrainedSketch,
@@ -2033,10 +2172,10 @@ class Feature:
     def PartitionFaceBySketchRefPoint(
         self,
         faces: Sequence[Face],
-        sketchPlane: str,
+        sketchPlane: Face | Datum,
         sketchUpEdge: Edge,
         sketch: ConstrainedSketch,
-        point: int,
+        point: ConstrainedSketchVertex | DatumPoint | InterestingPoint | Sequence[float] | NDArray,
         sketchOrientation: Literal[C.RIGHT, C.LEFT, C.TOP, C.BOTTOM] = RIGHT,
     ) -> Feature:
         """This method partitions one or more faces by sketching on a sketch plane and then projecting the
@@ -2081,7 +2220,7 @@ class Feature:
     def PartitionFaceBySketchThruAll(
         self,
         faces: Sequence[Face],
-        sketchPlane: str,
+        sketchPlane: Face | Datum,
         sketchPlaneSide: Literal[C.SIDE1, C.SIDE2],
         sketchUpEdge: str,
         sketch: ConstrainedSketch,
@@ -2128,7 +2267,7 @@ class Feature:
     @abaqus_method_doc
     def ReferencePoint(
         self,
-        point: Union[tuple, Vertex, InterestingPoint, MeshNode, Datum],
+        point: ConstrainedSketchVertex | InterestingPoint | MeshNode | DatumPoint | Sequence[float] | NDArray,
         instanceName: str = "",
     ) -> Feature:
         """This method creates a Feature object and a ReferencePoint object at the specified location.
@@ -2181,7 +2320,14 @@ class Feature:
     @abaqus_method_doc
     def WirePolyLine(
         self,
-        points: float,
+        points: (
+            Sequence[ConstrainedSketchVertex]
+            | Sequence[DatumPoint]
+            | Sequence[MeshNode]
+            | Sequence[InterestingPoint]
+            | Sequence[Sequence[float]]
+            | Sequence[ReferencePointType]
+        ),
         mergeType: Literal[C.MERGE, C.IMPRINT, C.SEPARATE] = IMPRINT,
         meshable: Boolean = ON,
     ) -> Feature:
