@@ -2,6 +2,8 @@ from __future__ import annotations
 
 from abqpy.decorators import abaqus_class_doc
 
+from .AbaqusNDarray import AbaqusNDarray
+
 
 @abaqus_class_doc
 class Keyword:
@@ -25,10 +27,10 @@ class Keyword:
     #: the data is suitable and if the InputFile.parse() method was called with the option
     #: usePyArray=True. In cases where large amounts of numerical data (i.e., large node
     #: arrays) are expected, it is recommended that you use the option usePyArray=True.
-    data: tuple = ()
+    data: tuple[tuple[float, ...], ...] | AbaqusNDarray = ()
 
     #: A KeywordSequence specifying the suboptions of the keyword.
     suboptions: str = ""
 
     #: A sequence of Strings specifying the comments.
-    comments: tuple = ()
+    comments: tuple[str, ...] = ()
