@@ -555,9 +555,9 @@ class ContactProperty(InteractionProperty):
         ----------
         repeatedContacts
             A Boolean specifying whether to enforce cohesive behavior for recurrent contacts at
-            nodes on the slave surface subsequent to ultimate failure. The default value is OFF.
+            nodes on the secondary surface subsequent to ultimate failure. The default value is OFF.
         eligibility
-            A SymbolicConstant specifying the eligible slave nodes. Possible values are
+            A SymbolicConstant specifying the eligible secondary nodes. Possible values are
             ALL_NODES, INITIAL_NODES, and SPECIFIED. The default value is ALL_NODES.
         defaultPenalties
             A Boolean specifying whether to use the default contact penalties. The default value is
@@ -670,7 +670,7 @@ class ContactProperty(InteractionProperty):
         return self.thermalConductance
 
     @abaqus_method_doc
-    def HeatGeneration(self, conversionFraction: float = 1, slaveFraction: float = 0):
+    def HeatGeneration(self, conversionFraction: float = 1, secondaryFraction: float = 0):
         """This method creates a GapHeatGeneration object.
 
         .. note::
@@ -683,20 +683,23 @@ class ContactProperty(InteractionProperty):
         conversionFraction
             A Float specifying the fraction of dissipated energy caused by friction or electric
             currents that is converted to heat. The default value is 1.0.
-        slaveFraction
-            A Float specifying the fraction of converted heat distributed to the slave surface.
+        secondaryFraction
+            A Float specifying the fraction of converted heat distributed to the secondary surface.
             The default value is 0.5.
 
+            .. versionchanged:: 2022
+                The argument ``slaveFraction`` was renamed to ``secondaryFraction``.
+
         Returns
         -------
         GapHeatGeneration
             A GapHeatGeneration object.
         """
-        self.heatGeneration = GapHeatGeneration(conversionFraction, slaveFraction)
+        self.heatGeneration = GapHeatGeneration(conversionFraction, secondaryFraction)
         return self.heatGeneration
 
     @abaqus_method_doc
-    def Radiation(self, masterEmissivity: float, slaveEmissivity: float, table: tuple):
+    def Radiation(self, mainEmissivity: float, secondaryEmissivity: float, table: tuple):
         """This method creates a Radiation object.
 
         .. note::
@@ -706,10 +709,16 @@ class ContactProperty(InteractionProperty):
 
         Parameters
         ----------
-        masterEmissivity
-            A Float specifying the emissivity of the master surface.
-        slaveEmissivity
-            A Float specifying the emissivity of the slave surface.
+        mainEmissivity
+            A Float specifying the emissivity of the main surface.
+
+            .. versionchanged:: 2022
+                The argument ``masterEmissivity`` was renamed to ``mainEmissivity``.
+        secondaryEmissivity
+            A Float specifying the emissivity of the secondary surface.
+
+            .. versionchanged:: 2022
+                The argument ``slaveEmissivity`` was renamed to ``secondaryEmissivity``.
         table
             A sequence of sequences of Floats specifying the following:Effective viewfactor, FF.Gap
             clearance, dd.
@@ -719,7 +728,7 @@ class ContactProperty(InteractionProperty):
         Radiation
             A Radiation object.
         """
-        self.radiation = Radiation(masterEmissivity, slaveEmissivity, table)
+        self.radiation = Radiation(mainEmissivity, secondaryEmissivity, table)
         return self.radiation
 
     @abaqus_method_doc
