@@ -57,11 +57,17 @@ class SurfaceToSurfaceContactStd(Interaction):
     #: is created.
     createStepName: str
 
-    #: A Region object specifying the master surface.
-    master: Region
+    #: A Region object specifying the name of the main surface.
+    #:
+    #: .. versionchanged:: 2022
+    #:     The ``master`` attribute was renamed to ``main``.
+    main: Region
 
-    #: A Region object specifying the slave surface.
-    slave: Region
+    #: A Region object specifying the name of the secondary surface.
+    #:
+    #: .. versionchanged:: 2022
+    #:     The ``slave`` attribute was renamed to ``secondary``.
+    secondary: Region
 
     #: A SymbolicConstant specifying the contact formulation. Possible values are FINITE and
     #: SMALL.
@@ -104,17 +110,17 @@ class SurfaceToSurfaceContactStd(Interaction):
     #: linearly over the step.
     amplitude: str = ""
 
-    #: A Float specifying the degree of smoothing used for deformable or rigid master surfaces
+    #: A Float specifying the degree of smoothing used for deformable or rigid main surfaces
     #: involved when **enforcement** = NODE_TO_SURFACE. The value given must lie between 0.0 and
     #: 0.5. The default value is 0.2.
     smooth: float = 0
 
-    #: A Float specifying the distance by which a slave node must penetrate the master
+    #: A Float specifying the distance by which a secondary node must penetrate the main
     #: surface before Abaqus/Standard abandons the current increment and tries again with a
     #: smaller increment. The default value is 0.0.
     hcrit: float = 0
 
-    #: A Float specifying a fraction of the end segment or facet edge length by which the master
+    #: A Float specifying a fraction of the end segment or facet edge length by which the main
     #: surface is to be extended to avoid numerical round-off errors associated with contact
     #: modeling. The value given must lie between 0.0 and 0.2. The default value is 0.1.
     extensionZone: float = 0
@@ -183,7 +189,7 @@ class SurfaceToSurfaceContactStd(Interaction):
     #: default value is NONE.
     surfaceSmoothing: SymbolicConstant = NONE
 
-    #: A Region object specifying the slave node sub-set for bonding, used only when the
+    #: A Region object specifying the secondary node sub-set for bonding, used only when the
     #: contact property CohesiveBehavior option specifies use.
     bondingSet: Region | None = None
 
@@ -194,7 +200,7 @@ class SurfaceToSurfaceContactStd(Interaction):
     #:     The ``handedness`` attribute was added.
     handedness: SymbolicConstant = RIGHT
 
-    #: A SymbolicConstant specifying the bolt normal adjustment formulation for all slave
+    #: A SymbolicConstant specifying the bolt normal adjustment formulation for all secondary
     #: nodes. Possible values are UNIFORM AXIAL COMPONENT and LOCATION DEPENDENT. The default
     #: value is UNIFORM AXIAL COMPONENT.
     #:
@@ -207,8 +213,8 @@ class SurfaceToSurfaceContactStd(Interaction):
         self,
         name: str,
         createStepName: str,
-        master: Region,
-        slave: Region,
+        main: Region,
+        secondary: Region,
         sliding: Literal[C.SMALL, C.FINITE],
         interactionProperty: str,
         interferenceType: Literal[C.UNIFORM, C.NONE, C.SHRINK_FIT] = NONE,
@@ -253,10 +259,16 @@ class SurfaceToSurfaceContactStd(Interaction):
         createStepName
             A String specifying the name of the step in which the SurfaceToSurfaceContactStd object
             is created.
-        master
-            A Region object specifying the master surface.
-        slave
-            A Region object specifying the slave surface.
+        main
+            A Region object specifying the name of the main surface.
+
+            .. versionchanged:: 2022
+                The ``master`` argument was renamed to ``main``.
+        secondary
+            A Region object specifying the name of the secondary surface.
+
+            .. versionchanged:: 2022
+                The ``slave`` argument was renamed to ``secondary``.
         sliding
             A SymbolicConstant specifying the contact formulation. Possible values are FINITE and
             SMALL.
@@ -292,15 +304,15 @@ class SurfaceToSurfaceContactStd(Interaction):
             interference is applied immediately at the beginning of the step and ramped down to zero
             linearly over the step.
         smooth
-            A Float specifying the degree of smoothing used for deformable or rigid master surfaces
+            A Float specifying the degree of smoothing used for deformable or rigid main surfaces
             involved when **enforcement** = NODE_TO_SURFACE. The value given must lie between 0.0 and
             0.5. The default value is 0.2.
         hcrit
-            A Float specifying the distance by which a slave node must penetrate the master
+            A Float specifying the distance by which a secondary node must penetrate the main
             surface before Abaqus/Standard abandons the current increment and tries again with a
             smaller increment. The default value is 0.0.
         extensionZone
-            A Float specifying a fraction of the end segment or facet edge length by which the master
+            A Float specifying a fraction of the end segment or facet edge length by which the main
             surface is to be extended to avoid numerical round-off errors associated with contact
             modeling. The value given must lie between 0.0 and 0.2. The default value is 0.1.
         adjustMethod
@@ -352,7 +364,7 @@ class SurfaceToSurfaceContactStd(Interaction):
             SurfaceToSurfaceContactStd interactions. Possible values are AUTOMATIC and NONE. The
             default value is NONE.
         bondingSet
-            A Region object specifying the slave node sub-set for bonding, used only when the
+            A Region object specifying the secondary node sub-set for bonding, used only when the
             contact property CohesiveBehavior option specifies use.
         handedness
             A SymbolicConstant specifying the bolt handedness formulation. Possible values are RIGHT
@@ -361,7 +373,7 @@ class SurfaceToSurfaceContactStd(Interaction):
             .. versionadded:: 2019
                 The ``normalAdjustment`` argument was added.
         normalAdjustment
-            A SymbolicConstant specifying the bolt normal adjustment formulation for all slave
+            A SymbolicConstant specifying the bolt normal adjustment formulation for all secondary
             nodes. Possible values are UNIFORM AXIAL COMPONENT and LOCATION DEPENDENT. The default
             value is UNIFORM AXIAL COMPONENT.
 
@@ -377,9 +389,11 @@ class SurfaceToSurfaceContactStd(Interaction):
 
     @abaqus_method_doc
     def swapSurfaces(self):
-        """This method switches the master and slave surfaces of a surface-to-surface contact pair.
+        """This method switches the main and secondary surfaces of a surface-to-surface contact pair. This
+        command is valid only for the step in which the interaction is created.
 
-        This command is valid only for the step in which the interaction is created.
+        .. versionchanged:: 2022
+            Master and slave were changed to main and secondary.
         """
         ...
 
@@ -448,15 +462,15 @@ class SurfaceToSurfaceContactStd(Interaction):
             interference is applied immediately at the beginning of the step and ramped down to zero
             linearly over the step.
         smooth
-            A Float specifying the degree of smoothing used for deformable or rigid master surfaces
+            A Float specifying the degree of smoothing used for deformable or rigid main surfaces
             involved when **enforcement** = NODE_TO_SURFACE. The value given must lie between 0.0 and
             0.5. The default value is 0.2.
         hcrit
-            A Float specifying the distance by which a slave node must penetrate the master
+            A Float specifying the distance by which a secondary node must penetrate the main
             surface before Abaqus/Standard abandons the current increment and tries again with a
             smaller increment. The default value is 0.0.
         extensionZone
-            A Float specifying a fraction of the end segment or facet edge length by which the master
+            A Float specifying a fraction of the end segment or facet edge length by which the main
             surface is to be extended to avoid numerical round-off errors associated with contact
             modeling. The value given must lie between 0.0 and 0.2. The default value is 0.1.
         adjustMethod
@@ -508,7 +522,7 @@ class SurfaceToSurfaceContactStd(Interaction):
             SurfaceToSurfaceContactStd interactions. Possible values are AUTOMATIC and NONE. The
             default value is NONE.
         bondingSet
-            A Region object specifying the slave node sub-set for bonding, used only when the
+            A Region object specifying the secondary node sub-set for bonding, used only when the
             contact property CohesiveBehavior option specifies use.
         handedness
             A SymbolicConstant specifying the bolt handedness formulation. Possible values are RIGHT
@@ -517,7 +531,7 @@ class SurfaceToSurfaceContactStd(Interaction):
             .. versionadded:: 2019
                 The ``normalAdjustment`` argument was added.
         normalAdjustment
-            A SymbolicConstant specifying the bolt normal adjustment formulation for all slave
+            A SymbolicConstant specifying the bolt normal adjustment formulation for all secondary
             nodes. Possible values are UNIFORM AXIAL COMPONENT and LOCATION DEPENDENT. The default
             value is UNIFORM AXIAL COMPONENT.
 
