@@ -7,7 +7,7 @@ from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
 from ..UtilityAndView.abaqusConstants import (
     ANALYSIS,
     DEFAULT,
-    DOMAIN,
+    ODB,
     OFF,
     ON,
     PERCENTAGE,
@@ -29,6 +29,10 @@ class JobFromInputFile(Job):
 
             import job
             mdb.jobs[name]
+
+    .. versionchanged:: 2023
+
+        The ``parallelizationMethodExplicit`` attribute was removed.
     """
 
     #: A Boolean specifying whether to retrieve the recommended memory settings from the last
@@ -50,7 +54,7 @@ class JobFromInputFile(Job):
     messages: MessageArray = []
 
     #: A tuple of Strings specifying the environment variables and their values.
-    environment: tuple = ()
+    environment: tuple[str, ...] = ()
 
     #: A String specifying the name of the new job. The name must be a valid Abaqus/CAE object
     #: name.
@@ -112,24 +116,21 @@ class JobFromInputFile(Job):
     #: A SymbolicConstant specifying whether to use the double precision version of
     #: Abaqus/Explicit. Possible values are SINGLE, FORCE_SINGLE, DOUBLE,
     #: DOUBLE_CONSTRAINT_ONLY, and DOUBLE_PLUS_PACK. The default value is SINGLE.
-    explicitPrecision: Literal[
-        C.SINGLE, C.FORCE_SINGLE, C.DOUBLE, C.DOUBLE_CONSTRAINT_ONLY, C.DOUBLE_PLUS_PACK
-    ] = SINGLE
+    explicitPrecision: Literal[C.SINGLE, C.FORCE_SINGLE, C.DOUBLE, C.DOUBLE_CONSTRAINT_ONLY, C.DOUBLE_PLUS_PACK] = (
+        SINGLE
+    )
 
     #: A SymbolicConstant specifying the precision of the nodal output written to the output
     #: database. Possible values are SINGLE and FULL. The default value is SINGLE.
     nodalOutputPrecision: Literal[C.SINGLE, C.FULL] = SINGLE
 
-    #: A SymbolicConstant specifying the parallelization method for Abaqus/Explicit.
-    #: Possible values are LOOP and DOMAIN. The default value is DOMAIN.
-    #:
-    #: .. versionchanged:: 2017
-    #:     The default value for parallelizationMethodExplicit is now `DOMAIN`
-    parallelizationMethodExplicit: Literal[C.LOOP, C.DOMAIN] = DOMAIN
-
     #: An Int specifying the number of domains for parallel execution in Abaqus/Explicit. When
-    #: **parallelizationMethodExplicit** = DOMAIN, **numDomains** must be a multiple of **numCpus**.
-    #: The default value is 1.
+    #: using more than 1 numCpus, numDomains must be a multiple of numCpus. The default value is 1.
+    #:
+    #: .. versionchanged:: 2023
+    #:
+    #:     The docs for this argument were updated to reflect that the ``parallelizationMethodExplicit``
+    #:     argument was removed in 2023.
     numDomains: int = 1
 
     #: A Boolean specifying whether to activate dyanmic load balancing for jobs running on
@@ -141,6 +142,15 @@ class JobFromInputFile(Job):
     #: values are DEFAULT, THREADS, and MPI. The default value is DEFAULT.
     multiprocessingMode: Literal[C.DEFAULT, C.THREADS, C.MPI] = DEFAULT
 
+    #: A SymbolicConstant specifying the type of license type being used in the case of the
+    #: DSLS SimUnit license model. Possible values are DEFAULT, TOKEN, and CREDIT. The default
+    #: value is DEFAULT.If the license model is not the DSLS SimUnit, the licenseType is not
+    #: available.
+    #:
+    #: .. versionadded:: 2022
+    #:     The ``licenseType`` attribute was added.
+    licenseType: Literal[C.DEFAULT, C.TOKEN, C.CREDIT] = DEFAULT
+
     @abaqus_method_doc
     def __init__(
         self,
@@ -160,10 +170,13 @@ class JobFromInputFile(Job):
             C.SINGLE, C.FORCE_SINGLE, C.DOUBLE, C.DOUBLE_CONSTRAINT_ONLY, C.DOUBLE_PLUS_PACK
         ] = SINGLE,
         nodalOutputPrecision: Literal[C.SINGLE, C.FULL] = SINGLE,
-        parallelizationMethodExplicit: Literal[C.LOOP, C.DOMAIN] = DOMAIN,
         numDomains: int = 1,
         activateLoadBalancing: Boolean = OFF,
         multiprocessingMode: Literal[C.DEFAULT, C.THREADS, C.MPI] = DEFAULT,
+        licenseType: Literal[C.DEFAULT, C.TOKEN, C.CREDIT] = DEFAULT,
+        getMemoryFromAnalysis: Boolean = ON,
+        numGPUs: int = 0,
+        resultsFormat: Literal[C.ODB, C.SIM, C.BOTH] = ODB,
     ):
         """This method creates an analysis job using an input file for the model definition.
 
@@ -172,6 +185,10 @@ class JobFromInputFile(Job):
 
                 mdb.JobFromInputFile
 
+        .. versionchanged:: 2023
+
+            The ``parallelizationMethodExplicit`` argument was removed.
+
         Parameters
         ----------
         name
@@ -226,16 +243,14 @@ class JobFromInputFile(Job):
         nodalOutputPrecision
             A SymbolicConstant specifying the precision of the nodal output written to the output
             database. Possible values are SINGLE and FULL. The default value is SINGLE.
-        parallelizationMethodExplicit
-            A SymbolicConstant specifying the parallelization method for Abaqus/Explicit.
-            Possible values are LOOP and DOMAIN. The default value is DOMAIN.
-
-            .. versionchanged:: 2017
-                The default value for parallelizationMethodExplicit is now `DOMAIN`
         numDomains
             An Int specifying the number of domains for parallel execution in Abaqus/Explicit. When
-            **parallelizationMethodExplicit** = DOMAIN, **numDomains** must be a multiple of **numCpus**.
-            The default value is 1.
+            using more than 1 numCpus, numDomains must be a multiple of numCpus. The default value is 1.
+
+            .. versionchanged:: 2023
+
+                The docs for this argument were updated to reflect that the ``parallelizationMethodExplicit``
+                argument was removed in 2023.
         activateLoadBalancing
             A Boolean specifying whether to activate dyanmic load balancing for jobs running on
             multiple processors with multiple domains in Abaqus/Explicit. The default value is OFF.
@@ -243,6 +258,14 @@ class JobFromInputFile(Job):
             A SymbolicConstant specifying whether an analysis is decomposed into threads or into
             multiple processes that communicate through a message passing interface (MPI). Possible
             values are DEFAULT, THREADS, and MPI. The default value is DEFAULT.
+        licenseType
+            A SymbolicConstant specifying the type of license type being used in the case of the
+            DSLS SimUnit license model. Possible values are DEFAULT, TOKEN, and CREDIT. The default
+            value is DEFAULT.If the license model is not the DSLS SimUnit, the licenseType is not
+            available.
+
+            .. versionchanged:: 2022
+                The ``licenseType`` argument was added.
         getMemoryFromAnalysis
             A Boolean specifying whether to retrieve the recommended memory settings from the last
             datacheck or analysis run and use those values in subsequent submissions. The default
@@ -284,13 +307,17 @@ class JobFromInputFile(Job):
             C.SINGLE, C.FORCE_SINGLE, C.DOUBLE, C.DOUBLE_CONSTRAINT_ONLY, C.DOUBLE_PLUS_PACK
         ] = SINGLE,
         nodalOutputPrecision: Literal[C.SINGLE, C.FULL] = SINGLE,
-        parallelizationMethodExplicit: Literal[C.LOOP, C.DOMAIN] = DOMAIN,
         numDomains: int = 1,
         activateLoadBalancing: Boolean = OFF,
         multiprocessingMode: Literal[C.DEFAULT, C.THREADS, C.MPI] = DEFAULT,
+        licenseType: Literal[C.DEFAULT, C.TOKEN, C.CREDIT] = DEFAULT,
     ):
         """This method modifies the JobFromInputFile object.
 
+        .. versionchanged:: 2023
+
+            The ``parallelizationMethodExplicit`` argument was removed.
+
         Parameters
         ----------
         type
@@ -338,16 +365,14 @@ class JobFromInputFile(Job):
         nodalOutputPrecision
             A SymbolicConstant specifying the precision of the nodal output written to the output
             database. Possible values are SINGLE and FULL. The default value is SINGLE.
-        parallelizationMethodExplicit
-            A SymbolicConstant specifying the parallelization method for Abaqus/Explicit.
-            Possible values are LOOP and DOMAIN. The default value is DOMAIN.
-
-            .. versionchanged:: 2017
-                The default value for parallelizationMethodExplicit is now `DOMAIN`
         numDomains
             An Int specifying the number of domains for parallel execution in Abaqus/Explicit. When
-            **parallelizationMethodExplicit** = DOMAIN, **numDomains** must be a multiple of **numCpus**.
-            The default value is 1.
+            using more than 1 numCpus, numDomains must be a multiple of numCpus. The default value is 1.
+
+            .. versionchanged:: 2023
+
+                The docs for this argument were updated to reflect that the ``parallelizationMethodExplicit``
+                argument was removed in 2023.
         activateLoadBalancing
             A Boolean specifying whether to activate dyanmic load balancing for jobs running on
             multiple processors with multiple domains in Abaqus/Explicit. The default value is OFF.
@@ -355,5 +380,10 @@ class JobFromInputFile(Job):
             A SymbolicConstant specifying whether an analysis is decomposed into threads or into
             multiple processes that communicate through a message passing interface (MPI). Possible
             values are DEFAULT, THREADS, and MPI. The default value is DEFAULT.
+        licenseType
+            A SymbolicConstant specifying the type of license type being used in the case of the
+            DSLS SimUnit license model. Possible values are DEFAULT, TOKEN, and CREDIT. The default
+            value is DEFAULT.If the license model is not the DSLS SimUnit, the licenseType is not
+            available.
         """
         ...
