@@ -8,7 +8,6 @@ from ..Mdb.MdbBase import MdbBase
 from ..UtilityAndView.abaqusConstants import (
     ANALYSIS,
     DEFAULT,
-    DOMAIN,
     ODB,
     OFF,
     ON,
@@ -58,7 +57,6 @@ class JobMdb(MdbBase):
             C.SINGLE, C.FORCE_SINGLE, C.DOUBLE, C.DOUBLE_CONSTRAINT_ONLY, C.DOUBLE_PLUS_PACK
         ] = SINGLE,
         nodalOutputPrecision: Literal[C.SINGLE, C.FULL] = SINGLE,
-        parallelizationMethodExplicit: Literal[C.LOOP, C.DOMAIN] = DOMAIN,
         numDomains: int = 1,
         activateLoadBalancing: Boolean = OFF,
         multiprocessingMode: Literal[C.DEFAULT, C.THREADS, C.MPI] = DEFAULT,
@@ -73,6 +71,10 @@ class JobMdb(MdbBase):
 
                 mdb.Job
 
+        .. versionchanged:: 2023
+
+            The ``parallelizationMethodExplicit`` argument was removed.
+
         Parameters
         ----------
         name
@@ -139,14 +141,14 @@ class JobMdb(MdbBase):
         nodalOutputPrecision
             A SymbolicConstant specifying the precision of the nodal output written to the output
             database. Possible values are SINGLE and FULL. The default value is SINGLE.
-        parallelizationMethodExplicit
-            A SymbolicConstant specifying the parallelization method for Abaqus/Explicit. This value
-            is ignored for Abaqus/Standard. Possible values are DOMAIN and LOOP. The default value
-            is DOMAIN.
         numDomains
             An Int specifying the number of domains for parallel execution in Abaqus/Explicit. When
-            **parallelizationMethodExplicit** = DOMAIN, **numDomains** must be a multiple of **numCpus**.
-            The default value is 1.
+            using more than 1 numCpus, numDomains must be a multiple of numCpus. The default value is 1.
+
+            .. versionchanged:: 2023
+
+                The docs for this argument were updated to reflect that the ``parallelizationMethodExplicit``
+                argument was removed in 2023.
         activateLoadBalancing
             A Boolean specifying whether to activate dyanmic load balancing for jobs running on
             multiple processors with multiple domains in Abaqus/Explicit. The default value is OFF.
@@ -160,6 +162,9 @@ class JobMdb(MdbBase):
             value is DEFAULT.If the license model is not the DSLS SimUnit, the licenseType is not
             available.
 
+            .. versionchanged:: 2022
+                The ``licenseType`` argument was added.
+
         Returns
         -------
         ModelJob
@@ -189,7 +194,6 @@ class JobMdb(MdbBase):
             memoryUnits,
             explicitPrecision,
             nodalOutputPrecision,
-            parallelizationMethodExplicit,
             numDomains,
             activateLoadBalancing,
             multiprocessingMode,
@@ -218,7 +222,6 @@ class JobMdb(MdbBase):
             C.SINGLE, C.FORCE_SINGLE, C.DOUBLE, C.DOUBLE_CONSTRAINT_ONLY, C.DOUBLE_PLUS_PACK
         ] = SINGLE,
         nodalOutputPrecision: Literal[C.SINGLE, C.FULL] = SINGLE,
-        parallelizationMethodExplicit: Literal[C.LOOP, C.DOMAIN] = DOMAIN,
         numDomains: int = 1,
         activateLoadBalancing: Boolean = OFF,
         multiprocessingMode: Literal[C.DEFAULT, C.THREADS, C.MPI] = DEFAULT,
@@ -234,6 +237,10 @@ class JobMdb(MdbBase):
 
                 mdb.JobFromInputFile
 
+        .. versionchanged:: 2023
+
+            The ``parallelizationMethodExplicit`` argument was removed.
+
         Parameters
         ----------
         name
@@ -288,14 +295,14 @@ class JobMdb(MdbBase):
         nodalOutputPrecision
             A SymbolicConstant specifying the precision of the nodal output written to the output
             database. Possible values are SINGLE and FULL. The default value is SINGLE.
-        parallelizationMethodExplicit
-            A SymbolicConstant specifying the parallelization method for Abaqus/Explicit. This value
-            is ignored for Abaqus/Standard. Possible values are DOMAIN and LOOP. The default value
-            is DOMAIN.
         numDomains
             An Int specifying the number of domains for parallel execution in Abaqus/Explicit. When
-            **parallelizationMethodExplicit** = DOMAIN, **numDomains** must be a multiple of **numCpus**.
-            The default value is 1.
+            using more than 1 numCpus, numDomains must be a multiple of numCpus. The default value is 1.
+
+            .. versionchanged:: 2023
+
+                The docs for this argument were updated to reflect that the ``parallelizationMethodExplicit``
+                argument was removed in 2023.
         activateLoadBalancing
             A Boolean specifying whether to activate dyanmic load balancing for jobs running on
             multiple processors with multiple domains in Abaqus/Explicit. The default value is OFF.
@@ -333,7 +340,6 @@ class JobMdb(MdbBase):
             memoryUnits,
             explicitPrecision,
             nodalOutputPrecision,
-            parallelizationMethodExplicit,
             numDomains,
             activateLoadBalancing,
             multiprocessingMode,
@@ -355,6 +361,7 @@ class JobMdb(MdbBase):
         saveFirst: Boolean = True,
         saveLast: Boolean = True,
         saveEvery: int | None = None,
+        licenseType: Literal[C.DEFAULT, C.TOKEN, C.CREDIT] = C.DEFAULT,
     ) -> OptimizationProcess:
         """This method creates an OptimizationProcess object.
 
@@ -401,6 +408,14 @@ class JobMdb(MdbBase):
             OPT_DATASAVE_SPECIFY_CYCLE. Abaqus saves file iterations for every nth iteration after
             iteration 1; if you set **saveEvery** = 3, Abaqus saves file iterations for cycles 1, 4, 7,
             and so on. The default value is None.
+        licenseType
+            A SymbolicConstant specifying the type of license type being used in the case of the DSLS SimUnit license
+            model. Possible values are DEFAULT, TOKEN, and CREDIT. The default value is DEFAULT.
+            For optimization job submission, the licenseType options are available regardless of the license model.
+
+            .. versionadded:: 2024
+
+                The argument ``licenseType`` was added.
 
         Returns
         -------
@@ -423,5 +438,6 @@ class JobMdb(MdbBase):
             saveFirst,
             saveLast,
             saveEvery,
+            licenseType,
         )
         return optimizationProcess
