@@ -166,6 +166,20 @@ class ElemType:
     #:     The ``nodeOffset`` attribute was added.
     nodeOffset: int | None = None
 
+    #: A Float specifying the linear kinematic conversion value.This argument is applicable
+    #: only to some Abaqus/Explicit elements.
+    #:
+    #: .. versionadded:: 2022
+    #:     The ``linearKinematicCtrl`` attribute was added.
+    linearKinematicCtrl: float | None = None
+
+    #: A Float specifying the initial gap opening.This parameter is applicable only to some
+    #: Abaqus/Standard elements.
+    #:
+    #: .. versionadded:: 2022
+    #:     The ``initialGapOpening`` attribute was added.
+    initialGapOpening: float | None = None
+
     @abaqus_method_doc
     def __init__(
         self,
@@ -196,6 +210,8 @@ class ElemType:
         quadraticBulkViscosity: float = 1,
         numFourierModes: int = 1,
         nodeOffset: int | None = None,
+        linearKinematicCtrl: float | None = None,
+        initialGapOpening: float | None = None,
     ):
         """This method creates an ElemType object.
 
@@ -316,6 +332,18 @@ class ElemType:
 
             .. versionadded:: 2019
                 The ``nodeOffset`` argument was added.
+        linearKinematicCtrl
+            A Float specifying the linear kinematic conversion value.This argument is applicable
+            only to some Abaqus/Explicit elements.
+
+            .. versionadded:: 2022
+                The ``linearKinematicCtrl`` argument was added.
+        initialGapOpening
+            A Float specifying the initial gap opening.This parameter is applicable only to some
+            Abaqus/Standard elements.
+
+            .. versionadded:: 2022
+                The ``initialGapOpening`` argument was added.
 
         Returns
         -------
