@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Sequence, Union, overload
+from typing import List, Sequence, Union, overload
 
 from typing_extensions import Literal
 
@@ -8,6 +8,7 @@ from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
 
 from ..UtilityAndView.abaqusConstants import OFF, Boolean, SymbolicConstant
 from ..UtilityAndView.abaqusConstants import abaqusConstants as C
+from .FieldBulkData import FieldBulkData
 from .FieldLocation import FieldLocation
 from .FieldLocationArray import FieldLocationArray
 from .FieldValueArray import FieldValueArray
@@ -64,7 +65,7 @@ class FieldOutput:
     #: the suffixes ('11', '22', '33', '12', '13', '23'). If **type** = VECTOR, the default value
     #: is **name** with the suffixes ('1', '2', '3'). If **type** = SCALAR, the default value is an
     #: empty sequence.
-    componentLabels: tuple = ()
+    componentLabels: tuple[str, ...] = ()
 
     #: A sequence of SymbolicConstants specifying which invariants should be calculated for
     #: this field. An empty sequence indicates that no invariants are valid for this field.
@@ -79,6 +80,9 @@ class FieldOutput:
     #: parameter applies only to tensor field outputs. The default value is OFF.
     isEngineeringTensor: Boolean = OFF
 
+    #: A sequence of FieldBulkData objects.
+    bulkDataBlocks: List[FieldBulkData]
+
     @overload
     @abaqus_method_doc
     def __init__(
@@ -162,8 +166,7 @@ class FieldOutput:
         ...
 
     @abaqus_method_doc
-    def __init__(self, *args, **kwargs):
-        ...
+    def __init__(self, *args, **kwargs): ...
 
     @overload
     def addData(
@@ -313,8 +316,7 @@ class FieldOutput:
         ...
 
     @abaqus_method_doc
-    def addData(self, *args, **kwargs):
-        ...
+    def addData(self, *args, **kwargs): ...
 
     @overload
     def getScalarField(self, invariant: SymbolicConstant):
@@ -358,8 +360,7 @@ class FieldOutput:
         ...
 
     @abaqus_method_doc
-    def getScalarField(self, *args, **kwargs):
-        ...
+    def getScalarField(self, *args, **kwargs): ...
 
     @overload
     @abaqus_method_doc
@@ -673,8 +674,7 @@ class FieldOutput:
         ...
 
     @abaqus_method_doc
-    def getTransformedField(self, *args, **kwargs):
-        ...
+    def getTransformedField(self, *args, **kwargs): ...
 
     def getConnectorFieldXformedToNodeA(self, deformationField: Union["FieldOutput", None] = None):
         """This method generates a new vector field containing the transformed component values of the parent
