@@ -137,7 +137,7 @@ class ContourOptions(DGContourOptions):
     reversedContourLegendRange: Boolean = OFF
 
     #: A tuple of Floats specifying the interval values when **intervalType** = USER_DEFINED.
-    intervalValues: float | None = None
+    intervalValues: tuple[float, ...] = ()
 
     #: A SymbolicConstant specifying the contour rendering method. Possible values are
     #: TEXTURE_MAPPED and TESSELLATED. The default value is TEXTURE_MAPPED.
@@ -219,7 +219,7 @@ class ContourOptions(DGContourOptions):
     #: contour legend. This setting hides the **autoMinValue** and **autoMaxValue** from the
     #: spectrum when **legendHideOutsideLimits** = ON.The default value is OFF.
     #:
-    #: .. versionadded:: 2019
+    #: ..versionadded:: 2019
     #:     The ``legendHideOutsideLimits`` attribute was added.
     legendHideOutsideLimits: Boolean = OFF
 
