@@ -1,28 +1,38 @@
 from __future__ import annotations
 
+from typing import Union
+
 from typing_extensions import Literal
 
 from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
 
+from ..BasicGeometry.VertexArray import VertexArray
+from ..Datum.DatumCsys import DatumCsys
 from ..Region.Region import Region
 from ..UtilityAndView.abaqusConstants import (
     ABSOLUTE_EQUAL,
+    ABSOLUTE_VALUE,
     AUTO,
     AXIS_1,
     DEMOLD_REGION,
+    FILTER_REGION,
     FREE_FORM,
     MAXIMUM,
+    MILLING_REGION,
     MINIMIZE,
     MINIMUM,
     MODEL,
     OFF,
     ON,
     OVERHANG_REGION,
+    RIBDESIGN_REGION,
     SUM,
+    TRUE,
     VECTOR,
     Boolean,
 )
 from ..UtilityAndView.abaqusConstants import abaqusConstants as C
+from .BeadFilter import BeadFilter
 from .BeadFixedRegion import BeadFixedRegion
 from .BeadGrowth import BeadGrowth
 from .BeadPenetrationCheck import BeadPenetrationCheck
@@ -58,9 +68,11 @@ from .StepOptionArray import StepOptionArray
 from .TopologyCyclicSymmetry import TopologyCyclicSymmetry
 from .TopologyDemoldControl import TopologyDemoldControl
 from .TopologyMemberSize import TopologyMemberSize
+from .TopologyMillingControl import TopologyMillingControl
 from .TopologyOverhangControl import TopologyOverhangControl
 from .TopologyPlanarSymmetry import TopologyPlanarSymmetry
 from .TopologyPointSymmetry import TopologyPointSymmetry
+from .TopologyRibDesign import TopologyRibDesign
 from .TopologyRotationalSymmetry import TopologyRotationalSymmetry
 from .TurnControl import TurnControl
 
@@ -77,7 +89,6 @@ class OptimizationTask(OptimizationTaskBase):
         operation: Literal[C.SUM, C.MINIMUM, C.MAXIMUM] = SUM,
         region: Literal[C.MODEL] = MODEL,
         shellLayer: Literal[C.BOTTOM, C.TOP, C.MAXIMUM, C.MINIMUM, C.MIDDLE] = MAXIMUM,
-        stepOperation: Literal[C.SUM, C.MINIMUM, C.MAXIMUM] = SUM,
         stepOptions: StepOptionArray | None = None,
     ) -> SingleTermDesignResponse:
         """This method creates a SingleTermDesignResponse object.
@@ -87,6 +98,10 @@ class OptimizationTask(OptimizationTaskBase):
 
                 mdb.models[name].optimizationTasks[name].SingleTermDesignResponse
 
+        .. versionchanged:: 2024
+
+            The argument `stepOperation` was removed.
+
         Parameters
         ----------
         name
@@ -109,9 +124,6 @@ class OptimizationTask(OptimizationTaskBase):
         shellLayer
             A SymbolicConstant specifying the location used for shell layer values. Possible values
             are BOTTOM, MAXIMUM, MIDDLE, MINIMUM, and TOP. The default value is MAXIMUM.
-        stepOperation
-            A SymbolicConstant specifying the operation used on values across steps and load cases.
-            Possible values are MAXIMUM, MINIMUM, and SUM. The default value is SUM.
         stepOptions
             A StepOptionArray object.
 
@@ -128,7 +140,6 @@ class OptimizationTask(OptimizationTaskBase):
             operation,
             region,
             shellLayer,
-            stepOperation,
             stepOptions,
         )
         return singleTermDesignResponse
@@ -221,6 +232,53 @@ class OptimizationTask(OptimizationTaskBase):
         )
         return optimizationConstraint
 
+    @abaqus_method_doc
+    def BeadFilter(
+        self,
+        name: str,
+        region: Region,
+        radius: float | None = None,
+        filterRadiusBy: Literal[C.ABSOLUTE_VALUE, C.RELATIVE] = ABSOLUTE_VALUE,
+        filterCheckRegion: Union[Literal[C.FILTER_REGION], Region] = FILTER_REGION,
+    ):
+        """This method creates a BeadFilter object.
+
+        .. note::
+            This function can be accessed by::
+
+                mdb.models[name].optimizationTasks[name].BeadFilter
+
+        .. versionadded:: 2023
+
+        The ``BeadFilter`` method was added.
+
+        Parameters
+        ----------
+        name
+            A String specifying the geometric restriction repository key.
+        region
+            A Region object specifying the region to which the geometric restriction is applied.
+        radius
+            A Float specifying the filter radius. The default value is double the average edge length of the model.
+        filterRadiusBy
+            The SymbolicConstant defines whether the filter radius is in absolute or relative units. For an absolute
+            radius, the value is ABSOLUTE_VALUE. For a relative radius, the value is RELATIVE. The default value is
+            ABSOLUTE_VALUE.
+        filterCheckRegion
+            The SymbolicConstant FILTER_REGION or a Region object specifying the filter check region. If the value is
+            FILTER_REGION, the value of the region is used as both the filter region and the filter check region.
+            The default value is FILTER_REGION.
+
+        Returns
+        -------
+        BeadFilter
+            A BeadFilter object.
+        """
+        self.geometricRestrictions[name] = geometricRestriction = BeadFilter(
+            name, region, radius, filterRadiusBy, filterCheckRegion
+        )
+        return geometricRestriction
+
     @abaqus_method_doc
     def BeadFixedRegion(
         self,
@@ -439,8 +497,8 @@ class OptimizationTask(OptimizationTaskBase):
         name: str,
         region: Region,
         csys: int | None = None,
-        masterPoint: str | None = None,
-        masterPointDetermination: Literal[C.SPECIFY, C.MINIMUM, C.MAXIMUM] = MAXIMUM,
+        mainPoint: str | None = None,
+        mainPointDetermination: Literal[C.SPECIFY, C.MINIMUM, C.MAXIMUM] = MAXIMUM,
         movementRestriction: Literal[C.MAGNITUDE, C.DIRECTION, C.VECTOR] = VECTOR,
         presumeFeasibleRegionAtStart: Boolean = ON,
         u1: Boolean = ON,
@@ -466,16 +524,22 @@ class OptimizationTask(OptimizationTaskBase):
             None or a DatumCsys object specifying the local coordinate system. If **csys** = None, the
             global coordinate system is used. When this member is queried, it returns an Int. The
             default value is None.
-        masterPoint
-            None or a Region object specifying the master point used when **masterPointDetermination** is
+        mainPoint
+            None or a Region object specifying the main point used when **mainPointDetermination** is
             SPECIFY. The default value is None.
-        masterPointDetermination
+
+            .. versionchanged:: 2022
+                The argument ``masterPoint`` was renamed to ``mainPoint``.
+        mainPointDetermination
             A SymbolicConstant specifying the rule for assigning point priority. Possible values are
             MAXIMUM, MINIMUM, and SPECIFY. The default value is MAXIMUM.
+
+            .. versionchanged:: 2022
+                The argument ``masterPointDetermination`` was renamed to ``mainPointDetermination``.
         movementRestriction
             A SymbolicConstant specifying whether movement in the region should follow only the
-            direction of the **masterPoint**, only the magnitude, or both the magnitude of the
-            **masterPoint** and the directions specified by **u1**, **u2** and **u3**. Possible values are
+            direction of the **mainPoint**, only the magnitude, or both the magnitude of the
+            **mainPoint** and the directions specified by **u1**, **u2** and **u3**. Possible values are
             DIRECTION, MAGNITUDE, and VECTOR. The default value is VECTOR.
         presumeFeasibleRegionAtStart
             A Boolean specifying whether to ignore the geometric restriction in the first design
@@ -502,8 +566,8 @@ class OptimizationTask(OptimizationTaskBase):
             name,
             region,
             csys,
-            masterPoint,
-            masterPointDetermination,
+            mainPoint,
+            mainPointDetermination,
             movementRestriction,
             presumeFeasibleRegionAtStart,
             u1,
@@ -520,8 +584,8 @@ class OptimizationTask(OptimizationTaskBase):
         region: Region,
         csys: int | None = None,
         drawAngle: float = 0,
-        masterPoint: str | None = None,
-        masterPointDetermination: Literal[C.SPECIFY, C.MINIMUM, C.MAXIMUM] = MAXIMUM,
+        mainPoint: str | None = None,
+        mainPointDetermination: Literal[C.SPECIFY, C.MINIMUM, C.MAXIMUM] = MAXIMUM,
         presumeFeasibleRegionAtStart: Boolean = ON,
         tolerance1: float = 0,
         tolerance2: float = 0,
@@ -553,12 +617,18 @@ class OptimizationTask(OptimizationTaskBase):
             default value is None.
         drawAngle
             A Float specifying the draw angle. The default value is 0.0.
-        masterPoint
-            None or a Region object specifying the master point used when **masterPointDetermination** is
+        mainPoint
+            None or a Region object specifying the main point used when **mainPointDetermination** is
             SPECIFY. The default value is None.
-        masterPointDetermination
+
+            .. versionchanged:: 2022
+                The argument ``masterPoint`` was renamed to ``mainPoint``.
+        mainPointDetermination
             A SymbolicConstant specifying the rule for assigning point priority. Possible values are
             MAXIMUM, MINIMUM, and SPECIFY. The default value is MAXIMUM.
+
+            .. versionchanged:: 2022
+                The argument ``masterPointDetermination`` was renamed to ``mainPointDetermination``.
         presumeFeasibleRegionAtStart
             A Boolean specifying whether to ignore the geometric restriction in the first design
             cycle. The default value is ON.
@@ -585,8 +655,8 @@ class OptimizationTask(OptimizationTaskBase):
             region,
             csys,
             drawAngle,
-            masterPoint,
-            masterPointDetermination,
+            mainPoint,
+            mainPointDetermination,
             presumeFeasibleRegionAtStart,
             tolerance1,
             tolerance2,
@@ -766,7 +836,7 @@ class OptimizationTask(OptimizationTaskBase):
         collisionCheckRegion: Literal[C.DEMOLD_REGION] = DEMOLD_REGION,
         csys: int | None = None,
         drawAngle: float = 0,
-        masterPointDetermination: Literal[C.MINIMUM, C.MAXIMUM] = MAXIMUM,
+        mainPointDetermination: Literal[C.MINIMUM, C.MAXIMUM] = MAXIMUM,
         presumeFeasibleRegionAtStart: Boolean = ON,
         tolerance1: float = 0,
         tolerance2: float = 0,
@@ -802,9 +872,12 @@ class OptimizationTask(OptimizationTaskBase):
             value is None.
         drawAngle
             A Float specifying the draw angle. The default value is 0.0.
-        masterPointDetermination
+        mainPointDetermination
             A SymbolicConstant specifying the rule for assigning point priority. Possible values are
             MAXIMUM and MINIMUM. The default value is MAXIMUM.
+
+            .. versionchanged:: 2022
+                The argument ``masterPointDetermination`` was renamed to ``mainPointDetermination``.
         presumeFeasibleRegionAtStart
             A Boolean specifying whether to ignore the geometric restriction in the first design
             cycle. The default value is ON.
@@ -832,7 +905,7 @@ class OptimizationTask(OptimizationTaskBase):
             collisionCheckRegion,
             csys,
             drawAngle,
-            masterPointDetermination,
+            mainPointDetermination,
             presumeFeasibleRegionAtStart,
             tolerance1,
             tolerance2,
@@ -849,6 +922,8 @@ class OptimizationTask(OptimizationTaskBase):
         maxThickness: float = 0,
         minThickness: float = 0,
         sizeRestriction: Literal[C.MINIMUM, C.MAXIMUM] = MINIMUM,
+        assignNodeGroupRegion: Boolean = OFF,
+        nodeGroupRegion: str = "",
     ) -> ShapeMemberSize:
         """This method creates a ShapeMemberSize object.
 
@@ -872,6 +947,16 @@ class OptimizationTask(OptimizationTaskBase):
         sizeRestriction
             A SymbolicConstant specifying whether to restrict the minimum or maximum thickness.
             Possible values are MAXIMUM and MINIMUM. The default value is MINIMUM.
+        assignNodeGroupRegion
+            A bool specifying whether to use the node group region. The default value is OFF.
+
+            .. versionadded:: 2022
+                The ``assignNodeGroupRegion`` argument was added.
+        nodeGroupRegion
+            A Node Region object specifying the check node group.
+
+            .. versionadded:: 2022
+                The ``nodeGroupRegion`` argument was added.
 
         Returns
         -------
@@ -884,6 +969,8 @@ class OptimizationTask(OptimizationTaskBase):
             maxThickness,
             minThickness,
             sizeRestriction,
+            assignNodeGroupRegion,
+            nodeGroupRegion,
         )
         return geometricRestriction
 
@@ -893,8 +980,9 @@ class OptimizationTask(OptimizationTaskBase):
         name: str,
         clientDirection: tuple,
         region: Region,
+        allowNonSymmetricMesh: Boolean = TRUE,
         csys: int | None = None,
-        masterPointDetermination: Literal[C.MINIMUM, C.MAXIMUM] = MAXIMUM,
+        mainPointDetermination: Literal[C.MINIMUM, C.MAXIMUM] = MAXIMUM,
         presumeFeasibleRegionAtStart: Boolean = ON,
         tolerance1: float = 0,
         tolerance2: float = 0,
@@ -919,13 +1007,22 @@ class OptimizationTask(OptimizationTaskBase):
             A Region object specifying the region to which the geometric restriction is applied.
             When used with a TopologyTask, there is no default value. When used with a ShapeTask,
             the default value is MODEL.
+        allowNonSymmetricMesh
+            A Boolean specifying whether to allow a nonsymmetric mesh for this geometric
+            restriction. The default value is TRUE.
+
+            .. versionadded:: 2021
+                The ``alloowNonSymmetricMesh`` argument was added.
         csys
             None or a DatumCsys object specifying the local coordinate system. If **csys** = None, the
             global coordinate system is used. When this member is queried, it returns an Int. The
             default value is None.
-        masterPointDetermination
-            A SymbolicConstant specifying the rule for determining the master node. Possible values
+        mainPointDetermination
+            A SymbolicConstant specifying the rule for determining the main node. Possible values
             are MAXIMUM and MINIMUM. The default value is MAXIMUM.
+
+            .. versionchanged:: 2022
+                The argument ``masterPointDetermination`` was renamed to ``mainPointDetermination``.
         presumeFeasibleRegionAtStart
             A Boolean specifying whether to ignore the geometric restriction in the first design
             cycle. The default value is ON.
@@ -948,8 +1045,9 @@ class OptimizationTask(OptimizationTaskBase):
             name,
             clientDirection,
             region,
+            allowNonSymmetricMesh,
             csys,
-            masterPointDetermination,
+            mainPointDetermination,
             presumeFeasibleRegionAtStart,
             tolerance1,
             tolerance2,
@@ -963,7 +1061,7 @@ class OptimizationTask(OptimizationTaskBase):
         name: str,
         region: Region,
         csys: int | None = None,
-        masterPointDetermination: Literal[C.MINIMUM, C.MAXIMUM] = MAXIMUM,
+        mainPointDetermination: Literal[C.MINIMUM, C.MAXIMUM] = MAXIMUM,
         presumeFeasibleRegionAtStart: Boolean = ON,
         tolerance1: float = 0,
         tolerance2: float = 0,
@@ -988,9 +1086,12 @@ class OptimizationTask(OptimizationTaskBase):
             None or a DatumCsys object specifying the symmetry point represented as the origin of a
             local coordinate system. If **csys** = None, the global coordinate system is used. When this
             member is queried, it returns an Int. The default value is None.
-        masterPointDetermination
-            A SymbolicConstant specifying the rule for determining the master node. Possible values
+        mainPointDetermination
+            A SymbolicConstant specifying the rule for determining the main node. Possible values
             are MAXIMUM and MINIMUM. The default value is MAXIMUM.
+
+            .. versionchanged:: 2022
+                The argument ``masterPointDetermination`` was renamed to ``mainPointDetermination``.
         presumeFeasibleRegionAtStart
             A Boolean specifying whether to ignore the geometric restriction in the first design
             cycle. The default value is ON.
@@ -1013,7 +1114,7 @@ class OptimizationTask(OptimizationTaskBase):
             name,
             region,
             csys,
-            masterPointDetermination,
+            mainPointDetermination,
             presumeFeasibleRegionAtStart,
             tolerance1,
             tolerance2,
@@ -1027,10 +1128,11 @@ class OptimizationTask(OptimizationTaskBase):
         name: str,
         clientDirection: tuple,
         region: Region,
+        allowNonSymmetricMesh: Boolean = TRUE,
         angle: float = 0,
         csys: int | None = None,
-        masterPoint: str | None = None,
-        masterPointDetermination: Literal[C.SPECIFY, C.MINIMUM, C.MAXIMUM] = MAXIMUM,
+        mainPoint: str | None = None,
+        mainPointDetermination: Literal[C.SPECIFY, C.MINIMUM, C.MAXIMUM] = MAXIMUM,
         presumeFeasibleRegionAtStart: Boolean = ON,
         startPoint: float | None = None,
         tolerance1: float = 0,
@@ -1056,6 +1158,12 @@ class OptimizationTask(OptimizationTaskBase):
             A Region object specifying the region to which the geometric restriction is applied.
             When used with a TopologyTask, there is no default value. When used with a ShapeTask,
             the default value is MODEL.
+        allowNonSymmetricMesh
+            A Boolean specifying whether to allow a nonsymmetric mesh for this geometric
+            restriction. The default value is TRUE.
+
+            .. versionadded:: 2021
+                The ``alloowNonSymmetricMesh`` argument was added.
         angle
             A Float specifying the segment size of the repeating pattern in degrees. If the **angle**
             value is 0, no repeating pattern is created. The default value is 0.0.
@@ -1063,12 +1171,18 @@ class OptimizationTask(OptimizationTaskBase):
             None or a DatumCsys object specifying the local coordinate system. If **csys** = None, the
             global coordinate system is used. When this member is queried, it returns an Int. The
             default value is None.
-        masterPoint
-            None or a Region object specifying the master point used when **masterPointDetermination** is
+        mainPoint
+            None or a Region object specifying the main point used when **mainPointDetermination** is
             SPECIFY. The default value is None.
-        masterPointDetermination
-            A SymbolicConstant specifying the rule for determining the master node. Possible values
+
+            .. versionchanged:: 2022
+                The argument ``masterPoint`` was renamed to ``mainPoint``.
+        mainPointDetermination
+            A SymbolicConstant specifying the rule for determining the main node. Possible values
             are MAXIMUM, MINIMUM, and SPECIFY. The default value is MAXIMUM.
+
+            .. versionchanged:: 2022
+                The argument ``masterPointDetermination`` was renamed to ``mainPointDetermination``.
         presumeFeasibleRegionAtStart
             A Boolean specifying whether to ignore the geometric restriction in the first design
             cycle. The default value is ON.
@@ -1094,10 +1208,11 @@ class OptimizationTask(OptimizationTaskBase):
             name,
             clientDirection,
             region,
+            allowNonSymmetricMesh,
             angle,
             csys,
-            masterPoint,
-            masterPointDetermination,
+            mainPoint,
+            mainPointDetermination,
             presumeFeasibleRegionAtStart,
             startPoint,
             tolerance1,
@@ -1443,8 +1558,8 @@ class OptimizationTask(OptimizationTaskBase):
         region: Region,
         csys: int | None = None,
         drawAngle: float = 0,
-        masterPoint: str | None = None,
-        masterPointDetermination: Literal[C.SPECIFY, C.MINIMUM, C.MAXIMUM] = MAXIMUM,
+        mainPoint: str | None = None,
+        mainPointDetermination: Literal[C.SPECIFY, C.MINIMUM, C.MAXIMUM] = MAXIMUM,
         presumeFeasibleRegionAtStart: Boolean = ON,
         tolerance1: float = 0,
         tolerance2: float = 0,
@@ -1475,12 +1590,18 @@ class OptimizationTask(OptimizationTaskBase):
             default value is None.
         drawAngle
             A Float specifying the draw angle. The default value is 0.0.
-        masterPoint
-            None or a Region object specifying the master point used when **masterPointDetermination** is
+        mainPoint
+            None or a Region object specifying the main point used when **mainPointDetermination** is
             SPECIFY. The default value is None.
-        masterPointDetermination
+
+            .. versionchanged:: 2022
+                The argument ``masterPoint`` was renamed to ``mainPoint``.
+        mainPointDetermination
             A SymbolicConstant specifying the rule for assigning point priority. Possible values are
             MAXIMUM, MINIMUM, and SPECIFY. The default value is MAXIMUM.
+
+            .. versionchanged:: 2022
+                The argument ``masterPointDetermination`` was renamed to ``mainPointDetermination``.
         presumeFeasibleRegionAtStart
             A Boolean specifying whether to ignore the geometric restriction in the first design
             cycle. The default value is ON.
@@ -1507,8 +1628,8 @@ class OptimizationTask(OptimizationTaskBase):
             region,
             csys,
             drawAngle,
-            masterPoint,
-            masterPointDetermination,
+            mainPoint,
+            mainPointDetermination,
             presumeFeasibleRegionAtStart,
             tolerance1,
             tolerance2,
@@ -1676,6 +1797,59 @@ class OptimizationTask(OptimizationTaskBase):
         )
         return geometricRestriction
 
+    @abaqus_method_doc
+    def TopologyMillingControl(
+        self,
+        name: str,
+        millingDirections: tuple,
+        region: Region,
+        csys: int | None = None,
+        millingCheckRegion: Literal[C.MILLING_REGION] = MILLING_REGION,
+        radius: float | None = None,
+    ) -> TopologyMillingControl:
+        """This method creates a TopologyMillingControl object.
+
+        .. note::
+            This function can be accessed by::
+
+                mdb.models[name].optimizationTasks[name].TopologyMillingControl
+
+        .. versionadded:: 2022
+            The ``TopologyMillingControl`` method was added.
+
+        Parameters
+        ----------
+        name
+            A String specifying the geometric restriction repository key.
+        millingDirections
+            A tuple of VertexArray objects of length 2 specifying the milling directions. Each point
+            can be specified through a tuple of coordinates instead of through a ConstrainedSketchVertex.
+        region
+            A Region object specifying the region to which the geometric restriction is applied.
+        csys
+            None or a DatumCsys object specifying the local coordinate system of the
+            **millingDirections**. If **csys** = None, the global coordinate system is used. When this
+            member is queried, it returns an Int indicating the identifier of the DatumCsys. The
+            default value is None.
+        millingCheckRegion
+            The SymbolicConstant MILLING_REGION or a Region object specifying the milling check
+            region. If the value is MILLING_REGION, the value of **region** is used as both the
+            milling control region and the milling check region. The default value is
+            MILLING_REGION.
+        radius
+            A Float specifying the radius for the collision check during the removal of the elements
+            for the milling criteria.
+
+        Returns
+        -------
+        TopologyMillingControl
+            A TopologyMillingControl object.
+        """
+        self.geometricRestrictions[name] = geometricRestriction = TopologyMillingControl(
+            name, millingDirections, region, csys, millingCheckRegion, radius
+        )
+        return geometricRestriction
+
     @abaqus_method_doc
     def TopologyOverhangControl(
         self,
@@ -1831,6 +2005,69 @@ class OptimizationTask(OptimizationTaskBase):
         )
         return geometricRestriction
 
+    @abaqus_method_doc
+    def TopologyRibDesign(
+        self,
+        name: str,
+        ribDirection: VertexArray,
+        ribThickness: float,
+        ribDistance: float,
+        region: Region,
+        csys: DatumCsys | None = None,
+        ribDesignCheckRegion: Union[Literal[C.RIBDESIGN_REGION], Region] = RIBDESIGN_REGION,
+    ):
+        """This method creates a TopologyRibDesign object.
+
+        .. note::
+            This function can be accessed by::
+
+                mdb.models[name].optimizationTasks[name].TopologyRibDesign
+
+        .. versionadded:: 2022
+
+            The ``TopologyRibDesign`` method was added.
+
+        Parameters
+        ----------
+        name
+            A String specifying the geometric restriction repository key.
+        ribDirection
+            A VertexArray object of length 2 specifying the out-of-plane growth direction of the ribs. Instead of
+            through a Vertex, each point can be specified through a tuple of coordinates.
+        ribThickness
+            A Float specifying the average thickness of the ribs.
+        ribDistance
+            A Float specifying the average distance between the rib centers. The distance must be larger than twice
+            the average element edge length.
+        region
+            A Region object specifying the region to which the geometric restriction is applied.
+            When used with a TopologyTask, there is no default value. When used with a ShapeTask,
+            the default value is MODEL.
+        csys
+            None or a DatumCsys object specifying the position of the symmetry point defined as the
+            origin of a local coordinate system. If **csys** = None, the global coordinate system is
+            used. When this member is queried, it returns an Int. The default value is None.
+        ribDesignCheckRegion
+            The SymbolicConstant RIBDESIGN_REGION or a Region object specifying the overhang check region. If the value
+            is OVERHANG_REGION, the value of region is used as both the overhang control region and the overhang check
+            region. The default value is RIBDESIGN_REGION.
+
+        Returns
+        -------
+        TopologyRibDesign
+            A TopologyRibDesign object.
+        """
+        self.geometricRestrictions[name] = geometricRestriction = TopologyRibDesign(
+            name,
+            ribDirection,
+            ribThickness,
+            ribDistance,
+            region,
+            csys,
+            ribDesignCheckRegion,
+        )
+        return geometricRestriction
+
     @abaqus_method_doc
     def TopologyRotationalSymmetry(
         self,
@@ -1885,8 +2122,8 @@ class OptimizationTask(OptimizationTaskBase):
         clientDirection: tuple,
         region: Region,
         csys: int | None = None,
-        masterPoint: str | None = None,
-        masterPointDetermination: Literal[C.SPECIFY, C.MINIMUM, C.MAXIMUM] = MAXIMUM,
+        mainPoint: str | None = None,
+        mainPointDetermination: Literal[C.SPECIFY, C.MINIMUM, C.MAXIMUM] = MAXIMUM,
         presumeFeasibleRegionAtStart: Boolean = ON,
         tolerance1: float = 0,
         tolerance2: float = 0,
@@ -1915,12 +2152,18 @@ class OptimizationTask(OptimizationTaskBase):
             None or a DatumCsys object specifying the local coordinate system. If **csys** = None, the
             global coordinate system is used. When this member is queried, it returns an Int. The
             default value is None.
-        masterPoint
-            None or a Region object specifying the master point used when **masterPointDetermination** is
+        mainPoint
+            None or a Region object specifying the main point used when **mainPointDetermination** is
             SPECIFY. The default value is None.
-        masterPointDetermination
+
+            .. versionchanged:: 2022
+                The argument ``masterPoint`` was renamed to ``mainPoint``.
+        mainPointDetermination
             A SymbolicConstant specifying the rule for assigning point priority. Possible values are
             MAXIMUM, MINIMUM, and SPECIFY. The default value is MAXIMUM.
+
+            .. versionchanged:: 2022
+                The argument ``masterPointDetermination`` was renamed to ``mainPointDetermination``.
         presumeFeasibleRegionAtStart
             A Boolean specifying whether to ignore the geometric restriction in the first design
             cycle. The default value is ON.
@@ -1944,8 +2187,8 @@ class OptimizationTask(OptimizationTaskBase):
             clientDirection,
             region,
             csys,
-            masterPoint,
-            masterPointDetermination,
+            mainPoint,
+            mainPointDetermination,
             presumeFeasibleRegionAtStart,
             tolerance1,
             tolerance2,
