@@ -69,6 +69,7 @@ class OptimizationTaskModel(ModelBase):
         nodeUpdateStrategy: Literal[C.AGGRESSIVE, C.NORMAL, C.CONSERVATIVE] = CONSERVATIVE,
         numTrackedModes: int = 5,
         updateShapeBasisVectors: Literal[C.EVERY_CYCLE, C.FIRST_CYCLE] = EVERY_CYCLE,
+        groupOperator: Boolean = OFF,
     ) -> BeadTask:
         """This method creates a BeadTask object.
 
@@ -145,6 +146,13 @@ class OptimizationTaskModel(ModelBase):
             A SymbolicConstant specifying whether to update shape basis vectors in the first design
             cycle or every design cycle. Possible values are EVERY_CYCLE and FIRST_CYCLE. The
             default value is EVERY_CYCLE.
+        groupOperator
+            A Boolean specifying whether the group in the design response will be evaluated using
+            the existing algorithm or a new algorithm based on Abaqus sensitivities. The default
+            value of False means that the existing algorithm will be used.
+
+            .. versionadded:: 2022
+                The ``groupOperator`` argument was added.
 
         Returns
         -------
@@ -173,6 +181,7 @@ class OptimizationTaskModel(ModelBase):
             nodeUpdateStrategy,
             numTrackedModes,
             updateShapeBasisVectors,
+            groupOperator,
         )
         return optimizationTask
 
@@ -223,6 +232,7 @@ class OptimizationTaskModel(ModelBase):
         triMaxAngle: float = 140,
         triMinAngle: float = 20,
         updateShapeBasisVectors: Literal[C.EVERY_CYCLE, C.FIRST_CYCLE] = EVERY_CYCLE,
+        groupOperator: Boolean = OFF,
     ) -> ShapeTask:
         """This method creates a ShapeTask object.
 
@@ -379,6 +389,13 @@ class OptimizationTaskModel(ModelBase):
             A SymbolicConstant specifying whether to update shape basis vectors in the first design
             cycle or every design cycle. Possible values are EVERY_CYCLE and FIRST_CYCLE. The
             default value is EVERY_CYCLE.
+        groupOperator
+            A Boolean specifying whether the group in the design response will be evaluated using
+            the existing algorithm or a new algorithm based on Abaqus sensitivities. The default
+            value of False means that the existing algorithm will be used.
+
+            .. versionadded:: 2022
+                The ``groupOperator`` argument was added.
 
         Returns
         -------
@@ -430,6 +447,7 @@ class OptimizationTaskModel(ModelBase):
             triMaxAngle,
             triMinAngle,
             updateShapeBasisVectors,
+            groupOperator,
         )
         return optimizationTask
 
@@ -448,6 +466,7 @@ class OptimizationTaskModel(ModelBase):
         stopCriteriaDesignCycle: int = 4,
         thicknessMoveLimit: float = 0,
         thicknessUpdateStrategy: Literal[C.AGGRESSIVE, C.NORMAL, C.CONSERVATIVE] = NORMAL,
+        groupOperator: Boolean = OFF,
     ) -> SizingTask:
         """This method creates a SizingTask object.
 
@@ -495,6 +514,13 @@ class OptimizationTaskModel(ModelBase):
             A SymbolicConstant specifying the strategy for how the thickness is updated in the
             method of moving asymptotes. Possible values are NORMAL, CONSERVATIVE, and AGGRESSIVE.
             The default value is NORMAL.
+        groupOperator
+            A Boolean specifying whether the group in the design response will be evaluated using
+            the existing algorithm or a new algorithm based on Abaqus sensitivities. The default
+            value of False means that the existing algorithm will be used.
+
+            .. versionadded:: 2022
+                The ``groupOperator`` argument was added.
 
         Returns
         -------
@@ -514,6 +540,7 @@ class OptimizationTaskModel(ModelBase):
             stopCriteriaDesignCycle,
             thicknessMoveLimit,
             thicknessUpdateStrategy,
+            groupOperator,
         )
         return optimizationTask
 
@@ -560,6 +587,7 @@ class OptimizationTaskModel(ModelBase):
         structuralMassDamping: float | None = None,
         viscousMassDamping: float | None = None,
         viscousStiffnessDamping: float | None = None,
+        groupOperator: Boolean = OFF,
     ) -> TopologyTask:
         """This method creates a TopologyTask object.
 
@@ -681,6 +709,13 @@ class OptimizationTaskModel(ModelBase):
         viscousStiffnessDamping
             None or a Float specifying the viscous stiffness damping for the task region. The
             default value is None.
+        groupOperator
+            A Boolean specifying whether the group in the design response will be evaluated using
+            the existing algorithm or a new algorithm based on Abaqus sensitivities. The default
+            value of False means that the existing algorithm will be used.
+
+            .. versionadded:: 2022
+                The ``groupOperator`` argument was added.
 
         Returns
         -------
@@ -721,5 +756,6 @@ class OptimizationTaskModel(ModelBase):
             structuralMassDamping,
             viscousMassDamping,
             viscousStiffnessDamping,
+            groupOperator,
         )
         return optimizationTask
