@@ -248,6 +248,14 @@ class ShapeTask(OptimizationTask):
     #: default value is EVERY_CYCLE.
     updateShapeBasisVectors: SymbolicConstant = EVERY_CYCLE
 
+    #: A Boolean specifying whether the group in the design response will be evaluated using
+    #: the existing algorithm or a new algorithm based on Abaqus sensitivities. The default
+    #: value of False means that the existing algorithm will be used.
+    #:
+    #: .. versionadded:: 2022
+    #:     The ``groupSensitivities`` attribute was added.
+    groupOperator: Boolean = OFF
+
     @abaqus_method_doc
     def __init__(
         self,
@@ -295,6 +303,7 @@ class ShapeTask(OptimizationTask):
         triMaxAngle: float = 140,
         triMinAngle: float = 20,
         updateShapeBasisVectors: Literal[C.EVERY_CYCLE, C.FIRST_CYCLE] = EVERY_CYCLE,
+        groupOperator: Boolean = OFF,
     ):
         """This method creates a ShapeTask object.
 
@@ -451,6 +460,13 @@ class ShapeTask(OptimizationTask):
             A SymbolicConstant specifying whether to update shape basis vectors in the first design
             cycle or every design cycle. Possible values are EVERY_CYCLE and FIRST_CYCLE. The
             default value is EVERY_CYCLE.
+        groupOperator
+            A Boolean specifying whether the group in the design response will be evaluated using
+            the existing algorithm or a new algorithm based on Abaqus sensitivities. The default
+            value of False means that the existing algorithm will be used.
+
+            .. versionadded:: 2022
+                The ``groupOperator`` argument was added.
 
         Returns
         -------
@@ -506,6 +522,7 @@ class ShapeTask(OptimizationTask):
         triMaxAngle: float = 140,
         triMinAngle: float = 20,
         updateShapeBasisVectors: Literal[C.EVERY_CYCLE, C.FIRST_CYCLE] = EVERY_CYCLE,
+        groupOperator: Boolean = OFF,
     ):
         """This method modifies the ShapeTask object.
 
@@ -659,5 +676,12 @@ class ShapeTask(OptimizationTask):
             A SymbolicConstant specifying whether to update shape basis vectors in the first design
             cycle or every design cycle. Possible values are EVERY_CYCLE and FIRST_CYCLE. The
             default value is EVERY_CYCLE.
+        groupOperator
+            A Boolean specifying whether the group in the design response will be evaluated using
+            the existing algorithm or a new algorithm based on Abaqus sensitivities. The default
+            value of False means that the existing algorithm will be used.
+
+            .. versionadded:: 2022
+                The ``groupOperator`` argument was added.
         """
         ...
