@@ -199,6 +199,14 @@ class TopologyTask(OptimizationTask):
     #: default value is None.
     viscousStiffnessDamping: float | None = None
 
+    #: A Boolean specifying whether the group in the design response will be evaluated using
+    #: the existing algorithm or a new algorithm based on Abaqus sensitivities. The default
+    #: value of False means that the existing algorithm will be used.
+    #:
+    #: .. versionadded:: 2022
+    #:     The ``groupSensitivities`` attribute was added.
+    groupOperator: Boolean = OFF
+
     @abaqus_method_doc
     def __init__(
         self,
@@ -242,6 +250,7 @@ class TopologyTask(OptimizationTask):
         structuralMassDamping: float | None = None,
         viscousMassDamping: float | None = None,
         viscousStiffnessDamping: float | None = None,
+        groupOperator: Boolean = OFF,
     ):
         """This method creates a TopologyTask object.
 
@@ -363,6 +372,13 @@ class TopologyTask(OptimizationTask):
         viscousStiffnessDamping
             None or a Float specifying the viscous stiffness damping for the task region. The
             default value is None.
+        groupOperator
+            A Boolean specifying whether the group in the design response will be evaluated using
+            the existing algorithm or a new algorithm based on Abaqus sensitivities. The default
+            value of False means that the existing algorithm will be used.
+
+            .. versionadded:: 2022
+                The ``groupOperator`` argument was added.
 
         Returns
         -------
@@ -413,6 +429,7 @@ class TopologyTask(OptimizationTask):
         structuralMassDamping: float | None = None,
         viscousMassDamping: float | None = None,
         viscousStiffnessDamping: float | None = None,
+        groupOperator: Boolean = OFF,
     ):
         """This method modifies the TopologyTask object.
 
@@ -527,5 +544,12 @@ class TopologyTask(OptimizationTask):
         viscousStiffnessDamping
             None or a Float specifying the viscous stiffness damping for the task region. The
             default value is None.
+        groupOperator
+            A Boolean specifying whether the group in the design response will be evaluated using
+            the existing algorithm or a new algorithm based on Abaqus sensitivities. The default
+            value of False means that the existing algorithm will be used.
+
+            .. versionadded:: 2022
+                The ``groupOperator`` argument was added.
         """
         ...
