@@ -1,11 +1,10 @@
 from __future__ import annotations
 
-from typing import Sequence, overload
+from typing import TYPE_CHECKING, Sequence, overload
 
 from typing_extensions import Literal
 
-# prevent circular imports
-from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
+from abqpy.decorators import abaqus_method_doc
 
 from ..BasicGeometry.Cell import Cell
 from ..BasicGeometry.CellArray import CellArray
@@ -19,6 +18,7 @@ from ..BasicGeometry.ReferencePoints import ReferencePoints
 from ..BasicGeometry.Vertex import Vertex
 from ..BasicGeometry.VertexArray import VertexArray
 from ..Datum.Datum import Datum
+from ..Datum.DatumCsys import DatumCsys
 from ..EngineeringFeature.EngineeringFeature import EngineeringFeature
 from ..Mesh.MeshEdge import MeshEdge
 from ..Mesh.MeshEdgeArray import MeshEdgeArray
@@ -53,10 +53,8 @@ from ..UtilityAndView.abaqusConstants import abaqusConstants as C
 from .AcisFile import AcisFile
 from .PartFeature import PartFeature
 
-
-@abaqus_class_doc
-class PartInstance:
-    ...
+if TYPE_CHECKING:
+    from ..Assembly.PartInstance import PartInstance
 
 
 class PartBase(PartFeature):
@@ -111,7 +109,7 @@ class PartBase(PartFeature):
     featuresById: dict[str, PartFeature] = {}
 
     #: A repository of Datum objects specifying all the datums in the part.
-    datums: list[Datum] = []
+    datums: dict[int, Datum] = {}
 
     #: A MeshElementArray object specifying all the elements in the part.
     elements: MeshElementArray = MeshElementArray([])
@@ -270,8 +268,7 @@ class PartBase(PartFeature):
         ...
 
     @abaqus_method_doc
-    def __init__(self, *args, **kwargs):
-        ...
+    def __init__(self, *args, **kwargs): ...
 
     def PartFromBooleanCut(self, name: str, instanceToBeCut: str, cuttingInstances: Sequence[PartInstance]):
         """This method creates a Part in the parts repository after subtracting or cutting the geometries of a
@@ -280,7 +277,7 @@ class PartBase(PartFeature):
         .. note::
             This function can be accessed by::
 
-                mdb.models[name].Part
+                mdb.models[name].PartFromBooleanCut
 
         Parameters
         ----------
@@ -317,7 +314,7 @@ class PartBase(PartFeature):
         .. note::
             This function can be accessed by::
 
-                mdb.models[name].Part
+                mdb.models[name].PartFromBooleanMerge
 
         Parameters
         ----------
@@ -359,7 +356,7 @@ class PartBase(PartFeature):
         .. note::
             This function can be accessed by::
 
-                mdb.models[name].Part
+                mdb.models[name].PartFromExtrude2DMesh
 
         Parameters
         ----------
@@ -409,7 +406,7 @@ class PartBase(PartFeature):
         .. note::
             This function can be accessed by::
 
-                mdb.models[name].Part
+                mdb.models[name].PartFromGeometryFile
 
         Parameters
         ----------
@@ -495,7 +492,7 @@ class PartBase(PartFeature):
         .. note::
             This function can be accessed by::
 
-                mdb.models[name].Part
+                mdb.models[name].PartFromInstanceMesh
 
         Parameters
         ----------
@@ -535,7 +532,7 @@ class PartBase(PartFeature):
         .. note::
             This function can be accessed by::
 
-                mdb.models[name].Part
+                mdb.models[name].PartFromMesh
 
         Parameters
         ----------
@@ -566,7 +563,7 @@ class PartBase(PartFeature):
         .. note::
             This function can be accessed by::
 
-                mdb.models[name].Part
+                mdb.models[name].PartFromMeshMirror
 
         Parameters
         ----------
@@ -613,7 +610,7 @@ class PartBase(PartFeature):
         .. note::
             This function can be accessed by::
 
-                mdb.models[name].Part
+                mdb.models[name].PartFromNodesAndElements
 
         Parameters
         ----------
@@ -665,7 +662,7 @@ class PartBase(PartFeature):
         .. note::
             This function can be accessed by::
 
-                mdb.models[name].Part
+                mdb.models[name].PartFromOdb
 
         Parameters
         ----------
@@ -739,7 +736,7 @@ class PartBase(PartFeature):
         .. note::
             This function can be accessed by::
 
-                mdb.models[name].Part
+                mdb.models[name].PartFromSection3DMeshByPlane
 
         Parameters
         ----------
@@ -793,7 +790,7 @@ class PartBase(PartFeature):
         .. note::
             This function can be accessed by::
 
-                mdb.models[name].Part
+                mdb.models[name].PartFromSubstructure
 
         Parameters
         ----------
@@ -842,7 +839,7 @@ class PartBase(PartFeature):
         .. note::
             This function can be accessed by::
 
-                mdb.models[name].Part
+                mdb.models[name].Part2DGeomFrom2DMesh
 
         Parameters
         ----------
@@ -1101,17 +1098,22 @@ class PartBase(PartFeature):
         ...
 
     @abaqus_method_doc
-    def getCoordinates(self, entity: str):
+    def getCoordinates(self, entity: str, csys: DatumCsys):
         """This method returns the coordinates of specified point.
 
         Parameters
         ----------
         entity
             A ConstrainedSketchVertex, Datum point, MeshNode, or ReferencePoint specifying the entity to query.
+        csys
+            A DatumCsys object specifying the desired coordinate system of the returned
+            coordinates. By default, coordinates are given in the global coordinate system.
+
+            .. versionadded:: 2022
+                The ``csys`` argument was added.
 
         Returns
         -------
-        tuple[float, float, float]
             A tuple of 3 Floats representing the coordinates of the specified point.
         """
         ...
