@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-from typing import Sequence
-
 from abqpy.decorators import abaqus_class_doc
 
 
@@ -19,4 +17,4 @@ class CurrentProbeValues:
 
     #: A tuple of Floats specifying the values obtained while probing. These values are updated
     #: constantly as the user moves the mouse over the object being probed.
-    values: Sequence[float] | None = None
+    values: tuple[float, ...] = ()
