@@ -3,5 +3,4 @@ from __future__ import annotations
 from .FXComposite import FXComposite
 
 
-class FXSrollArea(FXComposite):
-    ...
+class FXSrollArea(FXComposite): ...
