@@ -1,6 +1,7 @@
+from __future__ import annotations
+
 from .GUIPlugInCommands import GUIPluginToolset
 from .KernelPlugInCommands import KernelPluginToolset
 
 
-class PluginToolset(GUIPluginToolset, KernelPluginToolset):
-    ...
+class PluginToolset(GUIPluginToolset, KernelPluginToolset): ...
