@@ -24,4 +24,4 @@ class IMARegion:
     #: A tuple of Floats specifying the volume fractions, per material instance name. The
     #: length of the tuple corresponds to the number of material instance names, as established
     #: by the assigned Eulerian section.
-    fractionList: float | None = None
+    fractionList: tuple[float, ...] = ()
