@@ -149,6 +149,7 @@ class SectionOdb(OdbBase):
         centroid: Sequence[float] = (),
         shearCenter: Sequence[float] = (),
         profileEnd: str = "",
+        beamSectionOffset: tuple[float, float] = (0.0, 0.0),
     ) -> BeamSection:
         """This method creates a BeamSection object.
 
@@ -247,6 +248,14 @@ class SectionOdb(OdbBase):
             same as that of the start profile. This argument is valid only when **beamShape** = TAPERED.
             The default value is an empty string. This parameter is available for manipulating the
             model database but not for the ODB API.
+        beamSectionOffset
+            A pair of Floats specifying the X- and Y-coordinates to define an offset for the cross-section origin from
+            the beam axis with respect to the default (that is, without an offset) local (1, 2) axis system. The default
+            beamSectionOffset is (0, 0).
+
+            .. versionadded:: 2024
+
+                The argument `beamSectionOffset` was added.
 
         Returns
         -------
@@ -282,6 +291,7 @@ class SectionOdb(OdbBase):
             centroid,
             shearCenter,
             profileEnd,
+            beamSectionOffset,
         )
         return section
 
