@@ -295,6 +295,89 @@ class SessionBase:
     #: A repository of Drawing objects.
     drawings: dict[str, Drawing] = {}
 
+    @abaqus_method_doc
+    def View(
+        self,
+        name: str,
+        nearPlane: float,
+        farPlane: float,
+        width: float,
+        height: float,
+        projection: Literal[C.PERSPECTIVE, C.PARALLEL],
+        cameraPosition: tuple[float, float, float],
+        cameraUpVector: tuple[float, float, float],
+        cameraTarget: tuple[float, float, float],
+        viewOffsetX: float,
+        viewOffsetY: float,
+        autoFit: Boolean,
+        movieMode: Boolean = OFF,
+    ):
+        """This method creates a View object. Note:All dimensions and coordinates are specified in the model
+        coordinate system. Note:This method cannot be used to create a View for a Layer object.
+
+        .. note::
+            This function can be accessed by::
+
+                session.View
+
+        Parameters
+        ----------
+        name
+            A String specifying the name of the view (also used as the repository key). Possible
+            values are 'Front', 'Back', 'Top', 'Bottom', 'Left', 'Right', 'Iso', 'User-1', 'User-2',
+            'User-3', and 'User-4'. The object member associated with this argument is a
+            SymbolicConstant. Possible values of the **name** member are:FRONT, BACK, TOP, BOTTOM,
+            LEFT, RIGHT, ISO, USER1, USER2, USER3, and USER4.
+        nearPlane
+            A Float specifying the distance from the camera to the near clipping plane. Possible
+            values are **nearPlane** > 0.0.
+        farPlane
+            A Float specifying the distance from the camera to the far clipping plane when
+            **farPlaneMode** =SPECIFY. Possible values are **farPlane** > **nearPlane**.
+        width
+            A Float specifying the width of the front clipping plane. Possible values are **width** >
+            0.0.
+        height
+            A Float specifying the height of the front clipping plane. Possible values are **height**
+            > 0.0.
+        projection
+            A SymbolicConstant specifying the projection mode. Possible values are PERSPECTIVE and
+            PARALLEL.
+        cameraPosition
+            A sequence of three Floats specifying the camera position.
+        cameraUpVector
+            A sequence of three Floats specifying the camera's up vector (the screen's positive
+            **Y** axis). The initial value is (0, 0, 0).
+        cameraTarget
+            A sequence of three Floats specifying the center of the scene.
+        viewOffsetX
+            A Float specifying the amount to pan the model in the screen **X** direction as a fraction
+            of the viewport width. A positive value pans the model to the right. A negative value
+            pans the model to the left. The *viewOffsetX* and **viewOffsetY** arguments allow you to pan
+            the view without changing the position of the camera or the target (*cameraPosition* and
+            **cameraTarget** arguments to the View method). The resulting change in the view allows
+            you to pan a perspective display without producing an apparent rotation of the model.
+        viewOffsetY
+            A Float specifying the amount to pan the model in the screen **Y** direction as a fraction
+            of the viewport height. A positive value pans the model upward. A negative value pans
+            the model downward.
+        autoFit
+            A Boolean specifying whether the view is auto-fit when applied.
+        movieMode
+            A Boolean specifying whether or not the camera is in movie mode. The default value is
+            OFF.
+
+        Returns
+        -------
+        View
+            A View object.
+
+        Raises
+        ------
+        RangeError
+        """
+        ...
+
     @abaqus_method_doc
     def setValues(self, kernelMemoryLimit: float | None = None):
         """This method modifies the Session object.
@@ -476,8 +559,11 @@ class SessionBase:
             A sequence of canvas objects (viewports, text strings, or arrows) to print. The default
             is to print all canvas objects.
         compression
-            A Boolean specifying the format for an SVG file. It is only valid to use this argument
-            when **format** is SVG. Possible values are False (Uncompressed) and True (Compressed).
+            A Boolean specifying the format for an SVG file. It is valid to use this argument
+            only when **format** is SVG. Possible values are False (Uncompressed) and True (Compressed).
+
+            .. versionchanged:: 2022
+                It is "only" valid to use this argument ...
         """
         ...
 
