@@ -18,7 +18,7 @@ class ConstrainedSketchVertex:
     """
 
     #: A tuple of Floats specifying the*X*-, **Y**, and **Z** coordinates of the sketch vertex.
-    coords: float | None = None
+    coords: tuple[float, ...] = ()
 
     @abaqus_method_doc
     def Spot(self, point: Sequence[float]):
