@@ -166,6 +166,7 @@ class abaqusConstants(SymbolicConstant, Enum):
     ALLISO = "ALLISO"
     ALLOW_SUBCYCLING = "ALLOW_SUBCYCLING"
     ALLSTAR = "ALLSTAR"
+    ALL_CONTACT_SURFACES = "ALL_CONTACT_SURFACES"
     ALL_DAMAGE_STEPS = "ALL_DAMAGE_STEPS"
     ALL_DATUMS = "ALL_DATUMS"
     ALL_DIRECT = "ALL_DIRECT"
@@ -350,6 +351,7 @@ class abaqusConstants(SymbolicConstant, Enum):
     BUSHING = "BUSHING"
     BY_NUMBER = "BY_NUMBER"
     BY_SPACING = "BY_SPACING"
+    C = "C"
     C3D10 = "C3D10"
     C3D10E = "C3D10E"
     C3D10H = "C3D10H"
@@ -997,6 +999,7 @@ class abaqusConstants(SymbolicConstant, Enum):
     ELEMENT_CENTROID = "ELEMENT_CENTROID"
     ELEMENT_FACE = "ELEMENT_FACE"
     ELEMENT_FACE_INTEGRATION_POINT = "ELEMENT_FACE_INTEGRATION_POINT"
+    ELEMENT_MASS_SCALING = "ELEMENT_MASS_SCALING"
     ELEMENT_NODAL = "ELEMENT_NODAL"
     ELEMENT_NODES = "ELEMENT_NODES"
     ELEMENT_PRESELECT = "ELEMENT_PRESELECT"
@@ -1126,6 +1129,7 @@ class abaqusConstants(SymbolicConstant, Enum):
     FILLED_SQUARE = "FILLED_SQUARE"
     FILLED_TRI = "FILLED_TRI"
     FILTER = "FILTER"
+    FILTER_REGION = "FILTER_REGION"
     FINE = "FINE"
     FINER = "FINER"
     FINITE = "FINITE"
@@ -1276,6 +1280,7 @@ class abaqusConstants(SymbolicConstant, Enum):
     HARMONIC = "HARMONIC"
     HEADING = "HEADING"
     HEALER_TYPE = "HEALER_TYPE"
+    HEALER_PHASE = "HEALER_PHASE"
     HEATCAP = "HEATCAP"
     HEAT_FLUX = "HEAT_FLUX"
     HEAT_FLUX_AREA = "HEAT_FLUX_AREA"
@@ -1445,6 +1450,7 @@ class abaqusConstants(SymbolicConstant, Enum):
     LAYUP_MAP = "LAYUP_MAP"
     LAYUP_MAP_COLORS = "LAYUP_MAP_COLORS"
     LAYUP_ORIENTATION = "LAYUP_ORIENTATION"
+    LCP_CONTACT = "LCP_CONTACT"
     LEAD_ANALYSIS = "LEAD_ANALYSIS"
     LEAF_COLORS = "LEAF_COLORS"
     LEDGER = "LEDGER"
@@ -1937,6 +1943,7 @@ class abaqusConstants(SymbolicConstant, Enum):
     QUILT = "QUILT"
     QUINTIC = "QUINTIC"
     Q_VECTORS = "Q_VECTORS"
+    R = "R"
     R2D2 = "R2D2"
     R3D3 = "R3D3"
     R3D4 = "R3D4"
@@ -1945,6 +1952,7 @@ class abaqusConstants(SymbolicConstant, Enum):
     RADIATION_ALL = "RADIATION_ALL"
     RADIUS = "RADIUS"
     RAINBOW = "RAINBOW"
+    RAMBERG_OSGOOD = "RAMBERG_OSGOOD"
     RAMP = "RAMP"
     RANDOM_RESPONSE = "RANDOM_RESPONSE"
     RANGE = "RANGE"
@@ -2012,6 +2020,7 @@ class abaqusConstants(SymbolicConstant, Enum):
     REVERSE_MIRROR = "REVERSE_MIRROR"
     REVOLUTE = "REVOLUTE"
     REVOLUTION = "REVOLUTION"
+    RIBDESIGN_REGION = "RIBDESIGN_REGION"
     RIGHT = "RIGHT"
     RIGID = "RIGID"
     RIGID_BODY = "RIGID_BODY"
@@ -2025,6 +2034,8 @@ class abaqusConstants(SymbolicConstant, Enum):
     ROTATE = "ROTATE"
     ROTATION = "ROTATION"
     ROTATIONAL_ACCELERATION = "ROTATIONAL_ACCELERATION"
+    ROTATIONAL_CONTINUUM = "ROTATIONAL_CONTINUUM"
+    ROTATIONAL_STRUCTURAL = "ROTATIONAL_STRUCTURAL"
     ROTATIONAL_VELOCITY = "ROTATIONAL_VELOCITY"
     ROTATION_ACCELEROMETER = "ROTATION_ACCELEROMETER"
     ROTATION_ANGLE = "ROTATION_ANGLE"
@@ -2034,6 +2045,7 @@ class abaqusConstants(SymbolicConstant, Enum):
     RSH = "RSH"
     RSS = "RSS"
     RUNNING = "RUNNING"
+    S = "S"
     S1 = "S1"
     S2 = "S2"
     S3 = "S3"
@@ -2195,6 +2207,7 @@ class abaqusConstants(SymbolicConstant, Enum):
     SPECIFIED_LIMIT = "SPECIFIED_LIMIT"
     SPECIFIED_MODES = "SPECIFIED_MODES"
     SPECIFIED_NODAL_DIAMETER = "SPECIFIED_NODAL_DIAMETER"
+    SPECIFIED_SURFACES = "SPECIFIED_SURFACES"
     SPECIFY = "SPECIFY"
     SPECIFY_NUM_PTS = "SPECIFY_NUM_PTS"
     SPECIFY_ORIENT = "SPECIFY_ORIENT"
@@ -2603,6 +2616,13 @@ class abaqusConstants(SymbolicConstant, Enum):
     SS = "SS"
     TOKEN = "TOKEN"
     CREDIT = "CREDIT"
+    ANAND = "ANAND"
+    DARVEAUX = "DARVEAUX"
+    DOUBLE_POWER = "DOUBLE_POWER"
+    TIME_POWER_LAW = "TIME_POWER_LAW"
+    BINGHAM_PLASTIC = "BINGHAM_PLASTIC"
+    HERSCHEL_BULKLEY = "HERSCHEL_BULKLEY"
+    BILAMINA = "BILAMINA"
     REUSS = "REUSS"
     VOIGT = "VOIGT"
     INVERSED_MT = "INVERSED_MT"
