@@ -182,8 +182,7 @@ class XYData(tuple):
         ...
 
     @abaqus_method_doc
-    def __init__(self, *args, **kwargs):
-        ...
+    def __init__(self, *args, **kwargs): ...
 
     def XYDataFromFile(
         self,
@@ -368,6 +367,45 @@ class XYData(tuple):
         nodeLabels: Sequence[tuple[str, Union[int, str]]] = (),
         numericForm: Literal[C.COMPLEX_MAGNITUDE, C.COMPLEX_PHASE, C.REAL, C.IMAGINARY, C.COMPLEX_VAL_AT_ANGLE] = REAL,
         complexAngle: float = 0,
+        operator: (
+            Literal[
+                C.ADD,
+                C.SUBTRACT,
+                C.MULTIPLY,
+                C.DIVIDE,
+                C.POWER,
+                C.MINIMUM,
+                C.MAXIMUM,
+                C.AVERAGE,
+                C.RANGE,
+                C.SRSS,
+                C.ABSOLUTE,
+                C.UNARY_NEGATIVE,
+                C.COSINE,
+                C.HYPERBOLIC_COSINE,
+                C.INVERSE_COSINE,
+                C.SINE,
+                C.HYPERBOLIC_SINE,
+                C.INVERSE_SINE,
+                C.TANGENT,
+                C.HYPERBOLIC_TANGENT,
+                C.INVERSE_TANGENT,
+                C.EXPONENTIAL,
+                C.NATURAL_LOG,
+                C.LOG,
+                C.SQUARE_ROOT,
+                C.NORMALIZE,
+                C.DEG2RAD,
+                C.RAD2DEG,
+                C.SMOOTH,
+                C.SWAP,
+                C.AVERAGE_ALL,
+                C.MAXIMUM_ENVELOPE,
+                C.MINIMUM_ENVELOPE,
+                C.RANGE_ALL,
+            ]
+            | None
+        ) = None,
     ) -> list[XYData]:
         """This method creates a list of XYData objects by reading field data from an Odb object.
 
@@ -449,6 +487,15 @@ class XYData(tuple):
         complexAngle
             A Float specifying the angle (in degrees) at which to display results that contain
             complex numbers when **numericForm** = COMPLEX_VAL_AT_ANGLE. The default value is 0.
+        operator
+            A SymbolicConstant specifying the mathematical, trigonometric, logarithmic, exponential,
+            or other operations. Possible values are ADD, SUBTRACT, MULTIPLY, DIVIDE, POWER,
+            MINIMUM, MAXIMUM, AVERAGE, RANGE, SRSS, ABSOLUTE, UNARY_NEGATIVE, COSINE,
+            HYPERBOLIC_COSINE, INVERSE_COSINE, SINE, HYPERBOLIC_SINE, INVERSE_SINE, TANGENT,
+            HYPERBOLIC_TANGENT, INVERSE_TANGENT, EXPONENTIAL, NATURAL_LOG, LOG, SQUARE_ROOT,
+            NORMALIZE, DEG2RAD, RAD2DEG, SMOOTH, SWAP, AVERAGE_ALL, MAXIMUM_ENVELOPE,
+            MINIMUM_ENVELOPE, and RANGE_ALL. If no value is defined, no operation will be performed
+            on the data, and the data will be saved as is.
 
         Returns
         -------
@@ -662,23 +709,25 @@ class XYData(tuple):
         includeAllElements: Boolean = False,
         step: int | None = None,
         frame: int | None = None,
-        variable: Literal[
-            C.ELEMENT_FACE,
-            C.ELEMENT_NODAL,
-            C.S22,
-            C.WHOLE_ELEMENT,
-            C.NODAL,
-            C.INTEGRATION_POINT,
-            C.ELEMENT_CENTROID,
-            C.INVARIANT,
-            C.S11,
-            C.WHOLE_MODEL,
-            C.GENERAL_PARTICLE,
-            C.STEEL,
-            C.SNEG,
-            C.WHOLE_PART_INSTANCE,
-        ]
-        | None = None,
+        variable: (
+            Literal[
+                C.ELEMENT_FACE,
+                C.ELEMENT_NODAL,
+                C.S22,
+                C.WHOLE_ELEMENT,
+                C.NODAL,
+                C.INTEGRATION_POINT,
+                C.ELEMENT_CENTROID,
+                C.INVARIANT,
+                C.S11,
+                C.WHOLE_MODEL,
+                C.GENERAL_PARTICLE,
+                C.STEEL,
+                C.SNEG,
+                C.WHOLE_PART_INSTANCE,
+            ]
+            | None
+        ) = None,
         deformedMag: float | None = None,
         numericForm: Literal[C.COMPLEX_MAGNITUDE, C.COMPLEX_PHASE, C.REAL, C.IMAGINARY, C.COMPLEX_VAL_AT_ANGLE] = REAL,
         complexAngle: float = 0,
