@@ -199,43 +199,45 @@ def xyDataListFromField(
     nodeLabels: Sequence[tuple[str, Union[int, str]]] = (),
     numericForm: Literal[C.COMPLEX_MAGNITUDE, C.COMPLEX_PHASE, C.REAL, C.IMAGINARY, C.COMPLEX_VAL_AT_ANGLE] = REAL,
     complexAngle: float = 0,
-    operator: Literal[
-        C.ADD,
-        C.SUBTRACT,
-        C.MULTIPLY,
-        C.DIVIDE,
-        C.POWER,
-        C.MINIMUM,
-        C.MAXIMUM,
-        C.AVERAGE,
-        C.RANGE,
-        C.SRSS,
-        C.ABSOLUTE,
-        C.UNARY_NEGATIVE,
-        C.COSINE,
-        C.HYPERBOLIC_COSINE,
-        C.INVERSE_COSINE,
-        C.SINE,
-        C.HYPERBOLIC_SINE,
-        C.INVERSE_SINE,
-        C.TANGENT,
-        C.HYPERBOLIC_TANGENT,
-        C.INVERSE_TANGENT,
-        C.EXPONENTIAL,
-        C.NATURAL_LOG,
-        C.LOG,
-        C.SQUARE_ROOT,
-        C.NORMALIZE,
-        C.DEG2RAD,
-        C.RAD2DEG,
-        C.SMOOTH,
-        C.SWAP,
-        C.AVERAGE_ALL,
-        C.MAXIMUM_ENVELOPE,
-        C.MINIMUM_ENVELOPE,
-        C.RANGE_ALL,
-    ]
-    | None = None,
+    operator: (
+        Literal[
+            C.ADD,
+            C.SUBTRACT,
+            C.MULTIPLY,
+            C.DIVIDE,
+            C.POWER,
+            C.MINIMUM,
+            C.MAXIMUM,
+            C.AVERAGE,
+            C.RANGE,
+            C.SRSS,
+            C.ABSOLUTE,
+            C.UNARY_NEGATIVE,
+            C.COSINE,
+            C.HYPERBOLIC_COSINE,
+            C.INVERSE_COSINE,
+            C.SINE,
+            C.HYPERBOLIC_SINE,
+            C.INVERSE_SINE,
+            C.TANGENT,
+            C.HYPERBOLIC_TANGENT,
+            C.INVERSE_TANGENT,
+            C.EXPONENTIAL,
+            C.NATURAL_LOG,
+            C.LOG,
+            C.SQUARE_ROOT,
+            C.NORMALIZE,
+            C.DEG2RAD,
+            C.RAD2DEG,
+            C.SMOOTH,
+            C.SWAP,
+            C.AVERAGE_ALL,
+            C.MAXIMUM_ENVELOPE,
+            C.MINIMUM_ENVELOPE,
+            C.RANGE_ALL,
+        ]
+        | None
+    ) = None,
 ) -> list[XYData]:
     """This method creates a list of XYData objects by reading field data from an Odb object.
 
@@ -539,23 +541,25 @@ def XYDataFromPath(
     includeAllElements: Boolean = False,
     step: int | None = None,
     frame: int | None = None,
-    variable: Literal[
-        C.ELEMENT_FACE,
-        C.ELEMENT_NODAL,
-        C.S22,
-        C.WHOLE_ELEMENT,
-        C.NODAL,
-        C.INTEGRATION_POINT,
-        C.ELEMENT_CENTROID,
-        C.INVARIANT,
-        C.S11,
-        C.WHOLE_MODEL,
-        C.GENERAL_PARTICLE,
-        C.STEEL,
-        C.SNEG,
-        C.WHOLE_PART_INSTANCE,
-    ]
-    | None = None,
+    variable: (
+        Literal[
+            C.ELEMENT_FACE,
+            C.ELEMENT_NODAL,
+            C.S22,
+            C.WHOLE_ELEMENT,
+            C.NODAL,
+            C.INTEGRATION_POINT,
+            C.ELEMENT_CENTROID,
+            C.INVARIANT,
+            C.S11,
+            C.WHOLE_MODEL,
+            C.GENERAL_PARTICLE,
+            C.STEEL,
+            C.SNEG,
+            C.WHOLE_PART_INSTANCE,
+        ]
+        | None
+    ) = None,
     deformedMag: float | None = None,
     numericForm: Literal[C.COMPLEX_MAGNITUDE, C.COMPLEX_PHASE, C.REAL, C.IMAGINARY, C.COMPLEX_VAL_AT_ANGLE] = REAL,
     complexAngle: float = 0,
