@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import auto_all
 
-from abqpy import run  # noqa
+from abqpy import run, version_info  # noqa
 
 run(cae=True)
 auto_all.start_all()
@@ -17,12 +17,14 @@ from .Odb.Odb import Odb  # noqa
 from .Session.Session import Session  # noqa
 from .UtilityAndView import abaqusConstants  # noqa
 from .UtilityAndView.abaqusConstants import OFF, Boolean  # noqa
+from .UtilityAndView.AbaqusException import AbaqusException  # noqa
 from .UtilityAndView.BackwardCompatibility import BackwardCompatibility  # noqa
 from .UtilityAndView.SymbolicConstant import SymbolicConstant  # noqa
 from .UtilityAndView.User import *  # noqa
 
 session = Session()
 mdb = Mdb()
+version = version_info[0]
 
 backwardCompatibility = BackwardCompatibility()
 
